@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-# to contact the author : http://dar.linux.free.fr/email.html
+# to contact the author, see the AUTHOR file
 #######################################################################
 
 if [ $# -lt 1 ]; then
@@ -182,9 +182,6 @@ function GO {
 	else
 	    echo "--------> $1 FAILED : $*" > /dev/stderr
 	fi
-	if [ -x ~denis/Scripts/send_sms ] ; then
-	    ~denis/Scripts/send_sms "make check failed..."
-	fi
 	exit 1
     fi
 
