@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -64,7 +64,7 @@ extern "C"
 
 using namespace libdar;
 
-#define DAR_MANAGER_VERSION "1.8.3"
+#define DAR_MANAGER_VERSION "1.9.0"
 
 
 #define ONLY_ONCE "Only one -%c is allowed, ignoring this extra option"
@@ -89,6 +89,8 @@ static bool command_line(shell_interaction & dialog,
 			 bool & even_when_removed,
 			 bool & check_order,
 			 compression & algozip,
+			 U_I & compression_level,
+			 bool & change_compression,
 			 bool recursive); // true if called from op_batch
 static void show_usage(shell_interaction & dialog, const char *command);
 static void show_version(shell_interaction & dialog, const char *command);
@@ -96,7 +98,7 @@ static void show_version(shell_interaction & dialog, const char *command);
 #if HAVE_GETOPT_LONG
 static const struct option *get_long_opt();
 #endif
-static void op_create(shared_ptr<user_interaction> & dialog, const string & base, compression algozip, bool info_details);
+static void op_create(shared_ptr<user_interaction> & dialog, const string & base, compression algozip, U_I compr_level, bool info_details);
 static void op_add(shared_ptr<user_interaction> & dialog, database *dat, const string &arg, string fake, const infinint & min_digits, bool info_details);
 static void op_listing(shell_interaction & dialog, const database *dat, bool info_details);
 static void op_del(shared_ptr<user_interaction> & dialog, database *dat, S_I min, archive_num max, bool info_details);
@@ -126,9 +128,22 @@ static database *read_base(shared_ptr<user_interaction> & dialog,
 			   bool partial,
 			   bool partial_read_only,
 			   bool check_order);
-static void write_base(shared_ptr<user_interaction> & dialog, const string & filename, const database *base, bool overwrite);
+static void write_base(shared_ptr<user_interaction> & dialog,
+		       const string & filename,
+		       const database *base,
+		       bool overwrite,
+		       bool change_compression,
+		       compression new_compression,
+		       U_I compression_level);
 static vector<string> read_vector(shared_ptr<user_interaction> & dialog);
-static void finalize(shared_ptr<user_interaction> & dialog, operation op, database *dat, const string & base, bool info_details);
+static void finalize(shared_ptr<user_interaction> & dialog,
+		     operation op,
+		     database *dat,
+		     const string & base,
+		     bool info_details,
+		     bool change_compression,
+		     compression new_compression,
+		     U_I compression_level);
 static void action(shared_ptr<user_interaction> & dialog,
 		   operation op,
 		   database *dat,
@@ -175,6 +190,8 @@ S_I little_main(shared_ptr<user_interaction> & dialog, S_I argc, char * const ar
     bool even_when_removed;
     bool check_order;
     compression algozip;
+    U_I compression_level;
+    bool change_compression;
     shell_interaction *shelli = dynamic_cast<shell_interaction *>(dialog.get());
 
     if(!dialog)
@@ -199,6 +216,8 @@ S_I little_main(shared_ptr<user_interaction> & dialog, S_I argc, char * const ar
 		     even_when_removed,
 		     check_order,
 		     algozip,
+		     compression_level,
+		     change_compression,
 		     false))
 	return EXIT_SYNTAX;
 
@@ -223,19 +242,23 @@ S_I little_main(shared_ptr<user_interaction> & dialog, S_I argc, char * const ar
 	break;
     case listing:
 	partial_read_only = true;
+	if(change_compression)
+	    throw Erange("little_main", gettext("Cannot change compression when the requested operation is a read operation"));
 	break;
     case chbase:
     case where:
     case options:
     case dar:
 	partial_read = true;
+	if(change_compression)
+	    throw Erange("little_main", gettext("Cannot change compression when the requested operation only modifies the database header"));
 	break;
     default:
 	throw SRC_BUG;
     }
 
     if(op == create)
-	op_create(dialog, base, algozip, info_details);
+	op_create(dialog, base, algozip, compression_level, info_details);
     else
     {
 	if(info_details)
@@ -251,12 +274,12 @@ S_I little_main(shared_ptr<user_interaction> & dialog, S_I argc, char * const ar
 	    try
 	    {
 		action(dialog, op, dat, arg, num, rest, num2, date, base, info_details, true, ignore_dat_options, even_when_removed);
-		finalize(dialog, op, dat, base, info_details);
+		finalize(dialog, op, dat, base, info_details, change_compression, algozip, compression_level);
 	    }
 	    catch(Edata & e)
 	    {
 		dialog->message(string(gettext("Error met while processing operation: ")) + e.get_message());
-		finalize(dialog, op, dat, base, info_details);
+		finalize(dialog, op, dat, base, info_details, change_compression, algozip, compression_level);
 		throw;
 	    }
 	}
@@ -287,10 +310,13 @@ static bool command_line(shell_interaction & dialog,
 			 bool & even_when_removed,
 			 bool & check_order,
 			 compression & algozip,
+			 U_I & compression_level,
+			 bool & change_compression,
 			 bool recursive)
 {
     S_I lu, min;
     U_I max;
+    U_I compr_bs; // block compression is not used in dar_manager
     enum { date_not_set, date_set_by_w, date_set_by_9 } date_set = date_not_set;
 
     base = arg = "";
@@ -304,6 +330,8 @@ static bool command_line(shell_interaction & dialog,
     even_when_removed = false;
     check_order = true;
     algozip = compression::gzip;
+    compression_level = 9;
+    change_compression = false;
     string extra = "";
 
     try
@@ -342,7 +370,7 @@ static bool command_line(shell_interaction & dialog,
 		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    line_tools_split_path_basename(optarg, chem, filename);
-		    line_tools_check_basename(dialog, chem, filename, EXTENSION);
+		    line_tools_check_basename(dialog, chem, filename, EXTENSION, false);
 		    arg = (path(chem).append(filename)).display();
 		    break;
 		case 'l':
@@ -506,7 +534,13 @@ static bool command_line(shell_interaction & dialog,
 		case 'z':
 		    if(optarg == nullptr)
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
-		    algozip = string2compression(optarg);
+
+		    line_tools_split_compression_algo(optarg,
+						      1,         // no prefix (used for block anyway)
+						      algozip,
+						      compression_level,
+						      compr_bs); // we ignore this in dar_manager
+		    change_compression = true;
 		    break;
 		case ':':
 		    throw Erange("get_args", tools_printf(gettext(MISSING_ARG), char(optopt)));
@@ -584,6 +618,11 @@ static bool command_line(shell_interaction & dialog,
 	case add:
 	    if(rest.size() > 1)
 		dialog.message(gettext("Ignoring extra arguments on command line"));
+	    if(date_set == date_not_set) // --min-digits not set
+	    {
+		line_tools_check_min_digits(dialog, chem, filename, EXTENSION, date);
+		date_set = date_set_by_9;
+	    }
 	    break;
 	case chbase:
 	case where:
@@ -633,17 +672,16 @@ static bool command_line(shell_interaction & dialog,
     return true;
 }
 
-static void op_create(shared_ptr<user_interaction> & dialog, const string & base, compression algozip, bool info_details)
+static void op_create(shared_ptr<user_interaction> & dialog, const string & base, compression algozip, U_I compr_level, bool info_details)
 {
     database dat(dialog); // created empty;
 
-    dat.set_compression(algozip);
     if(info_details)
     {
         dialog->message(gettext("Creating file..."));
         dialog->message(gettext("Formatting file as an empty database..."));
     }
-    write_base(dialog, base, &dat, false);
+    write_base(dialog, base, &dat, false, true, algozip, compr_level);
     if(info_details)
         dialog->message(gettext("Database has been successfully created empty."));
 }
@@ -923,7 +961,7 @@ static void show_usage(shell_interaction & dialog, const char *command)
     dialog.printf(gettext("   -m <number>\t   move an archive within a given database.\n"));
     dialog.printf(gettext("   -i\t\t   user interactive mode\n"));
     dialog.printf(gettext("   -c\t\t   check database for dates order\n"));
-    dialog.printf(gettext("   -L <filename>   execute on a given database a batch of action as defined by\n"));
+    dialog.printf(gettext("   -@ <filename>   execute on a given database a batch of action as defined by\n"));
     dialog.printf(gettext("\t\t   the provided file.\n"));
     dialog.printf(gettext("   -h\t\t   displays this help information\n"));
     dialog.printf(gettext("   -V\t\t   displays software version\n"));
@@ -1020,12 +1058,23 @@ static database *read_base(shared_ptr<user_interaction> & dialog, const string &
     return ret;
 }
 
-static void write_base(shared_ptr<user_interaction> & dialog, const string & filename, const database *base, bool overwrite)
+static void write_base(shared_ptr<user_interaction> & dialog,
+		       const string & filename,
+		       const database *base,
+		       bool overwrite,
+		       bool change_compression,
+		       compression algozip,
+		       U_I compression_level)
 {
     thread_cancellation thr;
     database_dump_options dat_opt;
 
     dat_opt.set_overwrite(overwrite);
+    if(change_compression)
+    {
+	base->set_compression(algozip);
+	base->set_compression_level(compression_level);
+    }
     thr.block_delayed_cancellation(true);
     base->dump(filename, dat_opt);
     thr.block_delayed_cancellation(false);
@@ -1042,6 +1091,9 @@ static void op_interactive(shared_ptr<user_interaction> & dialog, database *dat,
     string input, input2;
     archive *arch = nullptr;
     vector <string> vectinput;
+    bool change_compression = false;
+    compression zipname;
+    U_I compr_level = 9;
     U_I more = 25;
     database_change_basename_options opt_change_name;
     database_change_path_options opt_change_path;
@@ -1075,8 +1127,8 @@ static void op_interactive(shared_ptr<user_interaction> & dialog, database *dat,
 	    dialog->printf(gettext(" p : modify path of archives \t b : modify basename of archives\n"));
 	    dialog->printf(gettext(" d : path to dar             \t o : options to dar\n"));
 	    dialog->printf(gettext(" w : write changes to file   \t s : database statistics\n"));
-	    dialog->printf(gettext(" a : Save as                 \t n : pause each 'n' line (zero for no pause)\n"));
-	    dialog->printf(gettext(" c : check date order\n\n"));
+	    dialog->printf(gettext(" c : check date order        \t z : change compression algorithm\n"));
+	    dialog->printf(gettext(" a : Save as                 \t n : pause each 'n' line (zero for no pause)\n\n"));
 	    dialog->printf(gettext(" q : quit\n\n"));
 	    dialog->printf(gettext(" Choice: "));
 
@@ -1119,15 +1171,27 @@ static void op_interactive(shared_ptr<user_interaction> & dialog, database *dat,
 		dat->set_dar_path(input);
 		saved = false;
 		break;
+	    case 'z':
+		input = dialog->get_string(gettext("New compression algorithm to use (none, gzip, bzip2, lzo, xz, zstd, lz4...)? "), true);
+		zipname = string2compression(input);
+		input = dialog->get_string(gettext("Compression level to use (usually an integer from 1 to 9)? "), true);
+		tmp_si = line_tools_str2signed_int(input);
+		if(tmp_si < 1)
+		    throw Erange("op_interactive", gettext("Compression level must be strictly positive"));
+		compr_level = (U_I)tmp_si;
+		dialog->message(gettext("Note: the new compression algorithm/level will be used when saving the database"));
+		change_compression = true;
+		saved = false;
+		break;
 	    case 'w':
 		dialog->message(gettext("Compressing and writing back database to file..."));
-		write_base(dialog, base, dat, true);
+		write_base(dialog, base, dat, true, change_compression, zipname, compr_level);
 		saved = true;
 		break;
 	    case 'a':
 		input = dialog->get_string(gettext("New database name: "), true);
 		dialog->message(gettext("Compressing and writing back database to file..."));
-		write_base(dialog, input, dat, false);
+		write_base(dialog, input, dat, false, change_compression, zipname, compr_level);
 		base = input;
 		saved = true;
 		break;
@@ -1295,7 +1359,9 @@ static void op_batch(shared_ptr<user_interaction> & dialog, database *dat, const
     bool ignore_dat_options;
     bool even_when_removed;
     bool check_order; // not used here
-    compression algozip; // not used here neither
+    compression algozip; // not used here neither but at the level of the function that called op_batch
+    U_I compression_level; // not used here neither but at the level of the function that called op_batch
+    bool change_compression; // not used here neither but at the level of the function that called op_batch
     shell_interaction *shelli = dynamic_cast<shell_interaction *>(dialog.get());
 
     if(shelli == nullptr)
@@ -1354,6 +1420,8 @@ static void op_batch(shared_ptr<user_interaction> & dialog, database *dat, const
 			     even_when_removed,
 			     check_order,
 			     algozip,
+			     compression_level,
+			     change_compression,
 			     true))
 		throw Erange("op_batch", tools_printf(gettext("Syntax error in batch file: %S"), &line));
 
@@ -1394,7 +1462,14 @@ static vector<string> read_vector(shared_ptr<user_interaction> & dialog)
     return ret;
 }
 
-static void finalize(shared_ptr<user_interaction> & dialog, operation op, database *dat, const string & base, bool info_details)
+static void finalize(shared_ptr<user_interaction> & dialog,
+		     operation op,
+		     database *dat,
+		     const string & base,
+		     bool info_details,
+		     bool change_compression,
+		     compression new_compression,
+		     U_I compression_level)
 {
     switch(op)
     {
@@ -1417,7 +1492,13 @@ static void finalize(shared_ptr<user_interaction> & dialog, operation op, databa
     case batch:
 	if(info_details)
 	    dialog->message(gettext("Compressing and writing back database to file..."));
-	write_base(dialog, base, dat, true);
+	write_base(dialog,
+		   base,
+		   dat,
+		   true, // overwriting
+		   change_compression,
+		   new_compression,
+		   compression_level);
 	break;
     default:
 	throw SRC_BUG;
