@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -68,7 +68,7 @@ extern "C"
 using namespace libdar;
 using namespace std;
 
-#define DAR_SLAVE_VERSION "1.5.3"
+#define DAR_SLAVE_VERSION "1.6.0"
 
 static bool command_line(shell_interaction & dialog,
 			 S_I argc,
@@ -113,7 +113,9 @@ static S_I little_main(shared_ptr<user_interaction> & dialog, S_I argc, char * c
 
     if(command_line(*ptr, argc, argv, chemin, filename, input_pipe, output_pipe, execute, min_digits))
     {
-	line_tools_check_basename(*dialog, chemin, filename, EXTENSION);
+	line_tools_check_basename(*dialog, chemin, filename, EXTENSION, false);
+	if(min_digits.is_zero())
+	    line_tools_check_min_digits(*dialog, chemin, filename, EXTENSION, min_digits);
 	libdar::libdar_slave slave(dialog,
 				   chemin,
 				   filename,
