@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 ******************************************************************** */
 
 #include "../my_config.h"
@@ -66,6 +66,14 @@
 #include <limits.h>
 #endif
 
+#if HAVE_GETOPT_H
+#include <getopt.h>
+#endif
+
+#if HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
+
 /// the compiler Nature MACRO
 #ifdef __GNUC__
 #define CC_NAT "GNUC"
@@ -83,7 +91,11 @@
 
 #define KEY_INPUT "split_input"
 #define KEY_OUTPUT "split_output"
-#define DAR_SPLIT_VERSION "1.1.3"
+#define DAR_SPLIT_VERSION "1.2.0"
+
+#define ERR_SYNTAX 1
+#define ERR_TIMER 2
+#define ERR_BUG 3
 
 static void usage(char *a);
 static void show_version(char *a);
@@ -93,48 +105,98 @@ static void purge_fd(int fd);
 static void stop_and_wait();
 static void pipe_handle_pause(int x);
 static void pipe_handle_end(int x);
-static void normal_read_to_multiple_write(char *filename, int sync_mode);
-static void multi_read_to_normal_write(char *filename);
+static void alarm_handle(int x);
+static void normal_read_to_multiple_write(char *filename, int sync_mode, unsigned int bs, unsigned int rate);
+static void multi_read_to_normal_write(char *filename, unsigned int bs, unsigned int rate, unsigned int count);
 static int open_read(char *filemane);  /* returns the filedescriptor */
 static int open_write(char *filename, int sync_mode); /* returns the filedescriptor */
+static void init_timer(unsigned int bufsize, unsigned int rate);
+static void rate_limit(unsigned int rate);
 
 static int fd_inter = -1;
+static int can_go = 0;
 
 int main(int argc, char *argv[])
 {
-    int key_index = 1; /* the expected position of the command */
+    signed int lu;
+
+	/* variables used to carry arguments */
+
+    int split_mode = 0; /* 0 : unset, 1 = normal_read , 2 = normal_write */
+    char *splitted_file = NULL;
+    int sync_mode = 0;
+    unsigned int bs = 0;
+    unsigned int rate = 0;
+    unsigned int count = 0;
 
 	/* command line parsing */
 
-    switch(argc)
+    while((lu = getopt(argc, argv, "-sb:hvr:c:")) != EOF)
     {
-    case 2:
-	if(strcmp("-v", argv[1]) == 0
-	   || strcmp("--version", argv[1]) == 0
-	   || strcmp("-V", argv[1]) == 0)
+	switch(lu)
 	{
+	case 1: /* non option argument due to the initial '-' in getopt string */
+	    if(split_mode == 0)
+	    {
+		if(strcmp(KEY_OUTPUT, optarg) == 0)
+		    split_mode = 1;
+		else if(strcmp(KEY_INPUT, optarg) == 0)
+		    split_mode = 2;
+		else
+		{
+		    fprintf(stderr, "Unknown mode %s. Please use either %s or %s\n",
+			    optarg,
+			    KEY_OUTPUT,
+			    KEY_INPUT);
+		    return ERR_SYNTAX;
+		}
+	    }
+	    else /* now reading the filename */
+		splitted_file = optarg;
+	    break;
+	case 's':
+	    sync_mode = 1;
+	    break;
+	case 'b':
+	    bs = atoi(optarg);
+	    break;
+	case 'r':
+	    rate = atoi(optarg);
+	    break;
+	case 'c':
+	    count = atoi(optarg);
+	    break;
+	case 'h':
+	    usage(argv[0]);
+	    return 0;
+	case 'v':
 	    show_version(argv[0]);
 	    return 0;
+	case ':':
+	    fprintf(stderr, "Missing parameter to option -%c\n", (char)optopt);
+	    return ERR_SYNTAX;
+	case '?':
+	    fprintf(stderr, "Ignoring unknown option -%c\n", (char)optopt);
+	    return ERR_SYNTAX;
 	}
-	else
-	{
-	    usage(argv[0]);
-	    return 1;
-	}
-    case 3:
-	break;
-    case 4:
-	if(strcmp(argv[1], "-s") != 0)
-	{
-	    usage(argv[0]);
-	    return 1;
-	}
-	else /* -s option has been given */
-	    key_index = 2;
-	break;
-    default:
-	usage(argv[0]);
-	return 1;
+    }
+
+    if(splitted_file == NULL)
+    {
+	fprintf(stderr, "Missing filename argument\n");
+	return ERR_SYNTAX;
+    }
+
+    if(count > 0 && split_mode != 2)
+    {
+	fprintf(stderr, "-c option is only available in split_input mode\n");
+	return ERR_SYNTAX;
+    }
+
+    if(sync_mode == 1 && split_mode != 1)
+    {
+	fprintf(stderr, "-s option is only available in split_output mode\n");
+	return ERR_SYNTAX;
     }
 
 	/* initialization */
@@ -144,16 +206,20 @@ int main(int argc, char *argv[])
 
 	/* execution */
 
-    if(strcmp(KEY_OUTPUT, argv[key_index]) == 0)
-	normal_read_to_multiple_write(argv[key_index + 1], key_index == 2);
-    else
-	if(strcmp(KEY_INPUT, argv[key_index]) == 0)
-	    if(key_index == 1)
-		multi_read_to_normal_write(argv[key_index + 1]);
-	    else
-		usage(argv[0]); /* -s option not available with KEY_INPUT */
-	else
-	    usage(argv[0]);
+    switch(split_mode)
+    {
+    case 1:
+	normal_read_to_multiple_write(splitted_file, sync_mode, bs, rate);
+	break;
+    case 2:
+	multi_read_to_normal_write(splitted_file, bs, rate, count);
+	break;
+    default:
+	fprintf(stderr, "missing read mode argument. Please user either %s or %s\n",
+		KEY_OUTPUT,
+		KEY_INPUT);
+	return ERR_SYNTAX;
+    }
 
 	/* normal exit */
 
@@ -162,10 +228,13 @@ int main(int argc, char *argv[])
 
 static void usage(char *a)
 {
-    fprintf(stderr, "usage: %s { %s | [-s] %s } <filename>\n", a, KEY_INPUT, KEY_OUTPUT);
+    fprintf(stderr, "\nusage: %s [-b <block size>] [-r <rate>] { [-c <count>] %s | [-s] %s } <filename>\n\n", a, KEY_INPUT, KEY_OUTPUT);
     fprintf(stderr, "- in %s mode, the data sent to %s's input is copied to the given filename\n  which may possibly be a non permanent output (retrying to write in case of failure)\n", KEY_OUTPUT, a);
     fprintf(stderr, "- in %s mode, the data is read from the given filename which may possibly\n  be non permanent input (retrying to read in case of failure) and copied to\n  %s's output\n", KEY_INPUT, a);
     fprintf(stderr, "\nThe -s option for %s mode leads %s to make SYNC writes, this avoid\n  operating system's caching to wrongly report a write as successful. This flag\n  reduces write performances but may be necessary when the end of tape is not\n  properly detected by %s\n", KEY_OUTPUT, a, a);
+    fprintf(stderr, "With -b option the amount of bytes sent per read or write system call does\n  not exceed this amount in byte\n");
+    fprintf(stderr, "With -r option the transfer is limited to the given byte/second rate\n");
+    fprintf(stderr, "With -c option dar_split will assume there is at most <count> tape and not ask\n   for further \n");
 }
 
 static void show_version(char *a)
@@ -245,10 +314,15 @@ static void pipe_handle_end(int x)
     exit(0);
 }
 
-
-static void normal_read_to_multiple_write(char *filename, int sync_mode)
+static void alarm_handle(int x)
 {
-    char* buffer = (char*) malloc(BUFSIZE);
+    can_go = 1;
+}
+
+static void normal_read_to_multiple_write(char *filename, int sync_mode, unsigned int bs, unsigned int rate)
+{
+    unsigned int bufsize = (bs == 0 ? BUFSIZE : bs);
+    char* buffer = (char*) malloc(bufsize);
     int lu;
     int ecru;
     int offset;
@@ -264,10 +338,12 @@ static void normal_read_to_multiple_write(char *filename, int sync_mode)
     }
 
     signal(SIGPIPE, pipe_handle_pause); /* handling case when writing to pipe that has no reader */
+    init_timer(bufsize, rate);
 
     while(run)
     {
-	lu = read(0, buffer, BUFSIZE);
+	rate_limit(rate);
+	lu = read(0, buffer, bufsize);
 	if(lu == 0) /* reached EOF */
 	    break; /* exiting the while loop, end of processing */
 
@@ -325,7 +401,7 @@ static void normal_read_to_multiple_write(char *filename, int sync_mode)
 		if(ecru > lu)
 		{
 		    fprintf(stderr, "BUG MET at line %d\n", __LINE__);
-		    break; /* end or processing */
+		    exit(ERR_BUG); /* end or processing */
 		}
 		else
 		{
@@ -361,14 +437,16 @@ static void normal_read_to_multiple_write(char *filename, int sync_mode)
 }
 
 
-static void multi_read_to_normal_write(char *filename)
+static void multi_read_to_normal_write(char *filename, unsigned int bs, unsigned int rate, unsigned int count)
 {
+    unsigned int bufsize = (bs == 0 ? BUFSIZE: bs);
     char* buffer = (char*)malloc(BUFSIZE);
     int lu;
     int ecru;
     int offset;
     int fd = buffer == NULL ? -1 : open_read(filename);
     int run = 1;
+    int iter = 0;
 
     if(buffer == NULL)
     {
@@ -377,17 +455,28 @@ static void multi_read_to_normal_write(char *filename)
     }
 
     signal(SIGPIPE, pipe_handle_end); /* handling case when writing to pipe that has no reader */
+    init_timer(bufsize, rate);
 
     while(run)
     {
-	lu = read(fd, buffer, BUFSIZE);
+	rate_limit(rate);
+	lu = read(fd, buffer, bufsize);
 	if(lu == 0) // EOF
 	{
 	    close(fd);
-	    fprintf(stderr, "No more data available from source, please do something!\n");
-	    stop_and_wait();
-	    open_read(filename);
-	    continue; /* start over the while loop */
+	    ++iter;
+	    if(count == 0 || iter < count)
+	    {
+		if(count == 0)
+		    fprintf(stderr, "No more data available from source, please do something!\n");
+		else
+		    fprintf(stderr, "No more data available from source number %d, please do something!\n", iter);
+		stop_and_wait();
+		open_read(filename);
+		continue; /* start over the while loop */
+	    }
+	    else
+		break; // we have done all tapes, ending the process
 	}
 	else
 	{
@@ -438,7 +527,7 @@ static void multi_read_to_normal_write(char *filename)
 	    if(ecru > lu)
 	    {
 		fprintf(stderr, "BUG MET at line %d\n", __LINE__);
-		break; /* end or processing */
+		exit(ERR_BUG); /* end or processing */
 	    }
 
 		/* starting from here no error occurred and lu >= ecru >= 0 */
@@ -495,3 +584,46 @@ static int open_read(char *filename)
 
     return fd;
 }
+
+static void init_timer(unsigned int bufsize, unsigned int rate)
+{
+    if(rate > 0)
+    {
+	struct timeval tm_int;
+	struct itimerval timer;
+
+		    /* program alarm() at correct rate */
+
+	signal(SIGALRM, alarm_handle);
+
+	tm_int.tv_sec = bufsize / rate ; /* integer division */
+	tm_int.tv_usec =  (bufsize % rate) * 1000000 / rate; /* remaining of the integer division expressed in microseconds */
+	timer.it_interval = tm_int;
+	timer.it_value = tm_int;
+
+	if(setitimer(ITIMER_REAL, &timer, NULL) != 0)
+	{
+	    fprintf(stderr, "Cannot set timer to control transfer rate: %s\n", strerror(errno));
+	    exit(ERR_TIMER);
+	}
+	can_go = 1;
+    }
+}
+
+static void rate_limit(unsigned int rate)
+{
+    if(rate > 0)
+    {
+	if(!can_go)
+	    pause();
+	    /* waiting for a signal (ALARM) some time fraction of time to
+	       not exceed the expected transfer rate
+	       if the incoming flow is faster, the input buffer will fill up to
+	       a time the OS will suspend the writer, dar_split will have enough
+	       data to write and continue at its pace. The OS may awake the writer
+	       at a later time for before the dar_split input get empty
+	    */
+
+	can_go = 0; // will be set to 1 by the timer handle
+    }
+}
