@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -155,7 +155,7 @@ int dar_suite_global(int argc,
     }
     catch(Efeature & e)
     {
-	general_report(string(gettext("NOT YET IMPLEMENTED FEATURE has been used: ")) + e.get_message());
+	general_report(string(gettext("NOT YET IMPLEMENTED FEATURE has been asked: ")) + e.get_message());
 	general_report(string(gettext("Please check documentation or upgrade your software if available")));
 	ret = EXIT_SYNTAX;
     }
