@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -54,7 +54,7 @@ extern "C"
 using namespace libdar;
 using namespace std;
 
-#define DAR_XFORM_VERSION "1.6.3"
+#define DAR_XFORM_VERSION "1.7.0"
 
 #define OPT_STRING  "s:S:p::wnhbVE:F:a::Qj^:3:9:"
 
@@ -374,7 +374,9 @@ static bool command_line(shell_interaction & dialog, S_I argc, char * const argv
         if(string(argv[optind]) != string(""))
 	{
             line_tools_split_path_basename(argv[optind], src_dir, src);
-	    line_tools_check_basename(dialog, *src_dir, src, EXTENSION);
+	    line_tools_check_basename(dialog, *src_dir, src, EXTENSION, false);
+	    if(src_min_digits.is_zero())
+		line_tools_check_min_digits(dialog, *src_dir, src, EXTENSION, src_min_digits);
 	}
         else
         {
@@ -382,7 +384,10 @@ static bool command_line(shell_interaction & dialog, S_I argc, char * const argv
             return false;
         }
         if(string(argv[optind+1]) != string(""))
+	{
             line_tools_split_path_basename(argv[optind+1], dst_dir, dst);
+	    line_tools_check_basename(dialog, *dst_dir, dst, EXTENSION, true);
+	}
         else
         {
             dialog.message(gettext("Invalid argument as destination archive"));
