@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file hide_file.hpp
@@ -49,6 +49,7 @@ public:
     virtual bool skip(const infinint & pos) override;
     virtual bool skip_to_eof() override;
     virtual bool skip_relative(S_I x) override;
+    virtual bool truncatable(const infinint & pos) const override { return false; };
     virtual infinint get_position() const override;
 
 protected:
@@ -64,10 +65,10 @@ protected:
     virtual void inherited_read_ahead(const infinint & amount) override { ref->read_ahead(amount); };
     virtual U_I inherited_read(char *a, U_I size) override;
     virtual void inherited_write(const char *a, size_t size) override;
+    virtual void inherited_truncate(const infinint & pos) override { throw Efeature("truncate a hide file"); };
     virtual void inherited_sync_write() override {};
     virtual void inherited_flush_read() override {};
     virtual void inherited_terminate() override {};
-
     virtual void fill_morceau() = 0;
         // the inherited classes have with this method
         // to fill the "morceau" variable that defines
