@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -59,6 +59,7 @@ using namespace libdar;
 static string build(string::iterator a, string::iterator b);
 static bool is_a_slice_available(user_interaction & ui, const string & base, const string & extension);
 static string retreive_basename(const string & base, const string & extension);
+static string retreive_basename2(const string & base);
 static void tools_localtime(const time_t & timep, struct tm *result);
 
 ////
@@ -789,11 +790,11 @@ void line_tools_crypto_split_algo_pass(const secu_string & all,
 		if(tmp == "none")
 		    algo = crypto_algo::none;
 		else
-		    if(tmp == "blowfish" || tmp == "bf" || tmp == "")
-			algo = crypto_algo::blowfish; // blowfish is the default cypher ("")
+		    if(tmp == "blowfish" || tmp == "bf")
+			algo = crypto_algo::blowfish;
 		    else
-			if(tmp == "aes" || tmp == "aes256")
-			    algo = crypto_algo::aes256;
+			if(tmp == "aes" || tmp == "aes256" || tmp == "")
+			    algo = crypto_algo::aes256; // AES is the default cypher ("")
 			else
 			    if(tmp == "twofish" || tmp == "twofish256")
 				algo = crypto_algo::twofish256;
@@ -1342,10 +1343,12 @@ void line_tools_display_features(user_interaction & dialog)
 	string time_accuracy = "";
 	string threadar_version = "";
 
-	dialog.printf(gettext("   Libz compression (gzip)      : %s"), YES_NO(compile_time::libz()));
-	dialog.printf(gettext("   Libbz2 compression (bzip2)   : %s"), YES_NO(compile_time::libbz2()));
-	dialog.printf(gettext("   Liblzo2 compression (lzo)    : %s"), YES_NO(compile_time::liblzo()));
-	dialog.printf(gettext("   Liblzma compression (xz)     : %s"), YES_NO(compile_time::libxz()));
+	dialog.printf(gettext("   gzip compression (libz)      : %s"), YES_NO(compile_time::libz()));
+	dialog.printf(gettext("   bzip2 compression (libbzip2) : %s"), YES_NO(compile_time::libbz2()));
+	dialog.printf(gettext("   lzo compression (liblzo2)    : %s"), YES_NO(compile_time::liblzo()));
+	dialog.printf(gettext("   xz compression (liblzma)     : %s"), YES_NO(compile_time::libxz()));
+	dialog.printf(gettext("   zstd compression (libzstd)   : %s"), YES_NO(compile_time::libzstd()));
+	dialog.printf(gettext("   lz4 compression (liblz4)     : %s"), YES_NO(compile_time::liblz4()));
 	dialog.printf(gettext("   Strong encryption (libgcrypt): %s"), YES_NO(compile_time::libgcrypt()));
 	dialog.printf(gettext("   Public key ciphers (gpgme)   : %s"), YES_NO(compile_time::public_key_cipher()));
 	dialog.printf(gettext("   Extended Attributes support  : %s"), YES_NO(compile_time::ea()));
@@ -1359,6 +1362,7 @@ void line_tools_display_features(user_interaction & dialog)
 	dialog.printf(gettext("   Furtive read mode support    : %s"), YES_NO(compile_time::furtive_read()));
 	dialog.printf(gettext("   Linux ext2/3/4 FSA support   : %s"), YES_NO(compile_time::FSA_linux_extX()));
 	dialog.printf(gettext("   Mac OS X HFS+ FSA support    : %s"), YES_NO(compile_time::FSA_birthtime()));
+	dialog.printf(gettext("   Linux statx() support        : %s"), YES_NO(compile_time::Linux_statx()));
 
 	switch(compile_time::system_endian())
 	{
@@ -1377,15 +1381,25 @@ void line_tools_display_features(user_interaction & dialog)
 	dialog.printf(gettext("   Detected system/CPU endian   : %s"), endy);
 	dialog.printf(gettext("   Posix fadvise support        : %s"), YES_NO(compile_time::posix_fadvise()));
 	dialog.printf(gettext("   Large dir. speed optimi.     : %s"), YES_NO(compile_time::fast_dir()));
-	if(compile_time::microsecond_read())
-	    time_accuracy = "1 microsecond";
+	if(compile_time::nanosecond_read())
+	    time_accuracy = "1 nanosecond";
 	else
-	    time_accuracy = "1 s";
+	{
+	    if(compile_time::microsecond_read())
+		time_accuracy = "1 microsecond";
+	    else
+		time_accuracy = "1 second";
+	}
 	dialog.printf(gettext("   Timestamp read accuracy      : %S"), &time_accuracy);
-	if(compile_time::microsecond_write())
-	    time_accuracy = "1 microsecond";
+	if(compile_time::nanosecond_write())
+	    time_accuracy = "1 nanosecond";
 	else
-	    time_accuracy = "1 s";
+	{
+	    if(compile_time::microsecond_write())
+		time_accuracy = "1 microsecond";
+	    else
+		time_accuracy = "1 second";
+	}
 	dialog.printf(gettext("   Timestamp write accuracy     : %S"), &time_accuracy);
 	dialog.printf(gettext("   Restores dates of symlinks   : %s"), YES_NO(compile_time::symlink_restore_dates()));
 	if(compile_time::libthreadar())
@@ -1393,8 +1407,9 @@ void line_tools_display_features(user_interaction & dialog)
 	else
 	    threadar_version = "";
 	dialog.printf(gettext("   Multiple threads (libthreads): %s %s"), YES_NO(compile_time::libthreadar()), threadar_version.c_str());
-	dialog.printf(gettext("   Delta compression support    : %s"), YES_NO(compile_time::librsync()));
-	dialog.printf(gettext("   Remote repository support    : %s"), YES_NO(compile_time::remote_repository()));
+	dialog.printf(gettext("   Delta compression (librsync) : %s"), YES_NO(compile_time::librsync()));
+	dialog.printf(gettext("   Remote repository (libcurl)  : %s"), YES_NO(compile_time::remote_repository()));
+	dialog.printf(gettext("   argon2 hashing (libargon2)   : %s"), YES_NO(compile_time::libargon2()));
     }
     catch(...)
     {
@@ -1429,39 +1444,63 @@ const char *line_tools_get_from_env(const char **env, const char *clef)
     return ret;
 }
 
-void line_tools_check_basename(user_interaction & dialog, const path & loc, string & base, const string & extension)
+void line_tools_check_basename(user_interaction & dialog, const path & loc, string & base, const string & extension, bool create)
 {
     NLS_SWAP_IN;
     try
     {
-	regular_mask suspect(string(".+\\.[1-9][0-9]*\\.")+extension, true);
+	regular_mask suspect(string(".+\\.[0-9]+\\.")+extension+string("$"), true);
+	regular_mask suspect2(string("\\.0*$"), true);
 	string old_path = (loc.append(base)).display();
 
-	    // is basename is suspect ?
-	if(!suspect.is_covered(base))
-	    return; // not a suspect basename
-
 	    // is there a slice available ?
 	if(is_a_slice_available(dialog, old_path, extension))
 	    return; // yes, thus basename is not a mistake
 
-	    // removing the suspicious end (.<number>.extension)
-	    // and checking the avaibility of such a slice
-
-	string new_base = retreive_basename(base, extension);
-	string new_path = (loc.append(new_base)).display();
-	if(is_a_slice_available(dialog, new_path, extension))
+	    // is basename is suspect
+	if(suspect.is_covered(base)) // full slice name
 	{
-	    try
+		// removing the suspicious end (.<number>.extension)
+		// and checking the avaibility of such a slice
+
+	    string new_base = retreive_basename(base, extension);
+	    string new_path = (loc.append(new_base)).display();
+
+	    if(is_a_slice_available(dialog, new_path, extension))
 	    {
-		dialog.pause(tools_printf(gettext("Warning, %S seems more to be a slice name than a base name. Do you want to replace it by %S ?"), &base, &new_base));
+		dialog.message(tools_printf(gettext("Warning, no archive exist with \"%S\" as basename, however a slice part of an archive which basename is \"%S\" exists. Assuming a shell completion occurred and using that basename instead"), &base, &new_base));
 		base = new_base;
 	    }
-	    catch(Euser_abort & e)
+	    else // no slice exist neither with that slice name
 	    {
-		dialog.message(tools_printf(gettext("OK, keeping %S as basename"), &base));
+		try
+		{
+		    if(create)
+		    {
+			dialog.pause(tools_printf(gettext("Warning, the provided basename \"%S\" may lead to confusion as it looks like a slice name. It is advise to rather use \"%S\" as basename instead. Do you want to change the basename accordingly?"), &base, &new_base));
+			base = new_base;
+		    }
+		}
+		catch(Euser_abort & e)
+		{
+		    dialog.message(tools_printf(gettext("OK, keeping %S as basename"), &base));
+		}
 	    }
 	}
+	else
+	    if(suspect2.is_covered(base))
+	    {
+		    // shell completed up to the slice number in a file
+
+		string new_base = retreive_basename2(base); // removing the ending dot eventually followed by zeros
+		string new_path = (loc.append(new_base)).display();
+
+		if(is_a_slice_available(dialog, new_path, extension))
+		{
+		    dialog.message(tools_printf(gettext("Warning, no archive exist with \"%S\" as basename, however a slice part of an archive which basename is \"%S\" exists. Assuming a shell completion occurred and using that basename instead"), &base, &new_base));
+		    base = new_base;
+		}
+	    }
     }
     catch(...)
     {
@@ -1471,6 +1510,33 @@ void line_tools_check_basename(user_interaction & dialog, const path & loc, stri
     NLS_SWAP_OUT;
 }
 
+void line_tools_check_min_digits(user_interaction & dialog, const path & loc, const string & base, const string & extension, infinint & num_digits)
+{
+    bool found = false;
+    string cur;
+
+    etage contents(dialog, loc.display().c_str(), datetime(0), datetime(0), false, false);
+
+    regular_mask slice = regular_mask(base + "\\.0*1\\." + extension + "$", true);
+
+    while(!found && contents.read(cur))
+    {
+	found = slice.is_covered(cur);
+	if(found)
+	{
+		// extract the number of digits from the slice name
+	    S_I index_last = cur.find_last_not_of(string(".")+extension);
+	    cur = string(cur.begin(), cur.begin() + index_last + 1);
+	    S_I index_first = cur.find_last_not_of("0123456789");
+	    if(num_digits.is_zero() && index_last - index_first > 1)
+	    {
+		num_digits = index_last - index_first;
+		dialog.printf(gettext("Auto detecting min-digits to be %i"), &num_digits);
+	    }
+	}
+    }
+}
+
 string line_tools_getcwd()
 {
     const U_I step = 1024;
@@ -1677,6 +1743,81 @@ delta_sig_block_size::fs_function_t line_tools_string_to_sig_block_size_function
     throw Erange("line_tools_string_to_sig_block_function", gettext("unknown name give for delta signature block len function"));
 }
 
+void line_tools_split_compression_algo(const char *arg, U_I base, compression & algo, U_I & level, U_I & block_size)
+{
+    if(arg == nullptr)
+        throw SRC_BUG;
+    else
+    {
+        string working = arg;
+	deque<string> split;
+	infinint tmp;
+
+	line_tools_split(working, ':', split);
+
+	switch(split.size())
+	{
+	case 1:
+	    if(!tools_my_atoi(working.c_str(), level))
+            {
+                    // argument to -z is not an integer, testing whether this is an algorithm
+                try
+                {
+                    algo = string2compression(working.c_str());
+                    level = 9; // argument is a compression algo, level is 9 by default
+                }
+                catch(Erange & e)
+                {
+                    throw Erange("split_compression_algo", tools_printf(gettext("%s does not name a compression \"[algorithm][:][level]\" , like for examples \"gzip\", \"lzo\", \"bzip2\", \"lzo:3\", \"gzip:2\", \"8\" or \"1\". Please review the man page about -z option"), working.c_str()));
+                }
+            }
+            else // argument is a compression level, algorithm is gzip by default
+                algo = compression::gzip;
+
+	    block_size = 0;
+	    break;
+	case 2:
+	    if(split[0] != "")
+		algo = string2compression(split[0]);
+	    else
+		algo = compression::gzip; // default algorithm
+
+	     if(split[1] != "")
+	    {
+		if(!tools_my_atoi(split[1].c_str(), level) || (level > 9 && algo != compression::zstd) || level < 1)
+		    throw Erange("split_compression_algo", gettext("Compression level must be between 1 and 9, included"));
+	    }
+	    else
+		level = 9; // default compression level
+
+	    block_size = 0;
+	    break;
+	case 3:
+	    if(split[0] != "")
+		algo = string2compression(split[0]);
+	    else
+		algo = compression::gzip;
+
+	    if(split[1] != "")
+	    {
+		if(!tools_my_atoi(split[1].c_str(), level) || (level > 9 && algo != compression::zstd) || level < 1)
+		    throw Erange("split_compression_algo", gettext("Compression level must be between 1 and 9, included"));
+	    }
+	    else
+		level = 9;
+
+	    tmp = tools_get_extended_size(split[2], base);
+	    block_size = 0;
+	    tmp.unstack(block_size);
+	    if(!tmp.is_zero())
+		throw Erange("split_compression_algo", gettext("Compression block size too large for this operating system"));
+	    break;
+	default:
+	    throw Erange("split_compression_algo", gettext("invalid argument given for compression scheme"));
+	}
+    }
+}
+
 ///////////////////
 
 static string build(string::iterator a, string::iterator b)
@@ -1703,7 +1844,7 @@ static bool is_a_slice_available(user_interaction & ui, const string & base, con
 	try
 	{
 	    etage contents = etage(ui, chem->display().c_str(), datetime(0), datetime(0), false, false);  // we don't care the dates here so we set them to zero
-	    regular_mask slice = regular_mask(rest + "\\.[1-9][0-9]*\\."+ extension, true);
+	    regular_mask slice = regular_mask(rest + "\\.[0-9]+\\."+ extension, true);
 
 	    while(!ret && contents.read(rest))
 		ret = slice.is_covered(rest);
@@ -1740,6 +1881,17 @@ static string retreive_basename(const string & base, const string & extension)
     return new_base;
 }
 
+static string retreive_basename2(const string & base)
+{
+    string new_base = base;
+    S_I index;
+
+    index = new_base.find_last_not_of(string("0")); // this will point before the last dot preceeding the zeros
+    new_base = string(new_base.begin(), new_base.begin()+index);
+
+    return new_base;
+}
+
 static void tools_localtime(const time_t & timep, struct tm *result)
 {
 #if HAVE_LOCALTIME_R
