@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file line_tools.hpp
@@ -269,11 +269,27 @@ extern const char *line_tools_get_from_env(const char **env, const char *clef);
     /// \param[in] loc the path where resides the slice
     /// \param[in,out] base the basename of the slice
     /// \param[in] extension the extension of dar's slices
+    /// \param[in] create whether this is a new archive that is about to be created by this name
     /// \note if user accepted the change of slice name proposed by libdar through dialog the base argument is changed
 extern void line_tools_check_basename(user_interaction & dialog,
 				      const path & loc,
 				      std::string & base,
-				      const std::string & extension);
+				      const std::string & extension,
+				      bool create);
+
+    /// if a slice number 1 is met with the provided basename, set the num_digits accordingly
+
+    /// \param[in,out] dialog for user interaction
+    /// \param[in] loc the path where are expected the slices to be present
+    /// \param[in] base the basename of the archive
+    /// \param[in] extension the extension of dar's slices
+    /// \param[in,out] num_digits the min width of slice number (0 padded numbers)
+void line_tools_check_min_digits(user_interaction & dialog,
+				 const path & loc,
+				 const std::string & base,
+				 const std::string & extension,
+				 infinint & num_digits);
+
 
     /// from a string with a range notation (min-max) extract the range values
 
@@ -435,6 +451,14 @@ extern std::deque<std::string> line_tools_substract_from_deque(const std::deque<
     /// \note throws Erange in case of error
 extern delta_sig_block_size::fs_function_t line_tools_string_to_sig_block_size_function(const std::string & funname);
 
+extern void line_tools_split_compression_algo(const char *arg,     ///< input string to analyse
+					      U_I base,            ///< base value for number suffix
+					      compression & algo,  ///< returned compression algorithm
+					      U_I & level,         ///< returned compression level
+					      U_I & block_size     ///< returned compression block size
+    );
+
+
     /// @}
 
 #endif
