@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file archive_aux.hpp
@@ -64,7 +64,8 @@ namespace libdar
 	none,  ///< no hashing algorithm
 	md5,   ///< MD5 algorithm
 	sha1,  ///< SHA1 algorithm
-	sha512 ///< SHA-512 algorithm
+	sha512,///< SHA-512 algorithm
+	argon2 ///< argon2 hash algo
     };
 
     	/// convert hash value to human readable string
