@@ -1376,6 +1376,12 @@ namespace libdar
 	    /// defines the FSA (Filesystem Specific Attribute) to only consider (by default all FSA activated at compilation time are considered)
 	void set_fsa_scope(const fsa_scope & scope) { x_scope = scope; };
 
+	    /// whether to ignore unix sockets while restoring
+	void set_ignore_unix_sockets(bool val) { x_ignore_unix_sockets = val; };
+
+	    /// whether to ignore fs_root and use in-place path stored in the archive
+	void set_in_place(bool arg) { x_in_place = arg; };
+
 
 	    /////////////////////////////////////////////////////////////////////
 	    // getting methods
@@ -1398,6 +1404,8 @@ namespace libdar
 	bool get_only_deleted() const { return x_only_deleted; };
 	bool get_ignore_deleted() const { return x_ignore_deleted; };
 	const fsa_scope & get_fsa_scope() const { return x_scope; };
+	bool get_ignore_unix_sockets() const { return x_ignore_unix_sockets; };
+	bool get_in_place() const { return x_in_place; };
 
     private:
 	mask * x_selection;
@@ -1418,6 +1426,8 @@ namespace libdar
 	bool x_only_deleted;
 	bool x_ignore_deleted;
 	fsa_scope x_scope;
+	bool x_ignore_unix_sockets;
+	bool x_in_place;
 
 	void destroy() noexcept;
 	void nullifyptr() noexcept;
@@ -1580,6 +1590,9 @@ namespace libdar
 	    /// defines the FSA (Filesystem Specific Attribute) to only consider (by default all FSA activated at compilation time are considered)
 	void set_fsa_scope(const fsa_scope & scope) { x_scope = scope; };
 
+	    /// whether to ignore fs_root and use in-place path stored in the archive
+	void set_in_place(bool arg) { x_in_place = arg; };
+
 
 	    /////////////////////////////////////////////////////////////////////
 	    // getting methods
@@ -1597,6 +1610,7 @@ namespace libdar
 	const infinint & get_hourshift() const { return x_hourshift; };
 	bool get_compare_symlink_date() const { return x_compare_symlink_date; };
 	const fsa_scope & get_fsa_scope() const { return x_scope; };
+	bool get_in_place() const { return x_in_place; };
 
     private:
 	mask * x_selection;
@@ -1613,6 +1627,7 @@ namespace libdar
 	infinint x_hourshift;
 	bool x_compare_symlink_date;
 	fsa_scope x_scope;
+	bool x_in_place;
 
 	void destroy() noexcept;
 	void nullifyptr() noexcept;
