@@ -69,7 +69,7 @@ namespace libdar
 	virtual bool skip(const infinint & pos) override;
 	virtual bool skip_to_eof() override;
 	virtual bool skip_relative(S_I x) override;
-	virtual bool truncatable(const infinint & pos) const override { return ref->truncatable(pos); };
+	virtual bool truncatable(const infinint & pos) const override;
 	virtual infinint get_position() const override { return buffer_offset + next; };
 
     protected:
