@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file cache_global.hpp
@@ -82,6 +82,7 @@ namespace libdar
         virtual bool skip(const infinint & pos) override { return buffer->skip(pos); };
         virtual bool skip_to_eof() override { return buffer->skip_to_eof(); };
         virtual bool skip_relative(S_I x) override { return buffer->skip_relative(x); };
+	virtual bool truncatable(const infinint & pos) const override { return buffer->truncatable(pos); };
         virtual infinint get_position() const override { return buffer->get_position(); };
 
 	    // expose cache specific methods
@@ -97,6 +98,7 @@ namespace libdar
 
 	    // inherted from generic_file
 	virtual void inherited_read_ahead(const infinint & amount) override { buffer->read_ahead(amount); };
+	virtual void inherited_truncate(const infinint & pos) override { buffer->truncate(pos); };
 	virtual void inherited_sync_write() override { buffer->sync_write(); ptr->sync_write(); };
 	virtual void inherited_flush_read() override { buffer->flush_read();  };
 	virtual void inherited_terminate() override { buffer->terminate(); ptr->terminate(); };
