@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -34,7 +34,7 @@ using namespace std;
 namespace libdar
 {
 
-    cat_delta_signature::cat_delta_signature(generic_file *f, compressor *c)
+    cat_delta_signature::cat_delta_signature(generic_file *f, proto_compressor *c)
     {
 	init();
 
