@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file compile_time_features.hpp
@@ -78,9 +78,18 @@ namespace libdar
 	    /// returns whether libdar is dependent on liblxz/liblzma and if so has xz compression/decompression available
 	bool libxz() noexcept;
 
+	    /// returns whether libdar is dependent on libzstd and if so has zstd compression/decompression available
+	bool libzstd() noexcept;
+
+	    /// returns whether libdar is dependen in liblz4 and if so has lz4 compression/decompression available
+	bool liblz4() noexcept;
+
 	    /// returns whether libdar is dependent on libgcrypt and if so has strong encryption and hashing features available
 	bool libgcrypt() noexcept;
 
+	    /// returns whether libdar is dependent on libargon2 and if it has thus argon2 hash algorithm feature available
+	bool libargon2() noexcept;
+
 	    /// returns whether libdar can support furtive read mode when run by privileged user
 	bool furtive_read() noexcept;
 
@@ -107,12 +116,21 @@ namespace libdar
 	    /// returns whether libdar has been built with support for HFS+ FSA
 	bool FSA_birthtime() noexcept;
 
-	    /// returns whether libdar is able to read timestamps at a microsecond accuracy
+	    /// returns whether libdar has been built with support for Linux statx()
+	bool Linux_statx() noexcept;
+
+	    /// returns whether libdar is able to read timestamps at least at microsecond accuracy
 	bool microsecond_read() noexcept;
 
-	    /// returns whether libdar is able to write timestamps at a microsecond accuracy
+	    /// returns whether libdar is able to read timestamps at least at nanosecond accuracy
+	bool nanosecond_read() noexcept;
+
+	    /// returns whether libdar is able to write timestamps at least at microsecond accuracy
 	bool microsecond_write() noexcept;
 
+	    /// returns whether libdar is able to write timestamps at least at nanosecond accuracy
+	bool nanosecond_write() noexcept;
+
 	    /// returns whether libdar is able to restore dates of symlinks
 	bool symlink_restore_dates() noexcept;
 
