@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -187,6 +187,7 @@ namespace libdar
 		// was used for these versions
 	    break;
 	case 5:
+	case 6:
 	    f.read((char *)&flag, 1);
 	    if((flag & STATUS_PLUS_FLAG_ME) != 0)
 		base = create_crc_from_file(f, false);
@@ -273,6 +274,7 @@ namespace libdar
 	    case 3:
 	    case 4:
 	    case 5:
+	    case 6:
 		sta_plus.read(f, db_version);
 		last_mod[k] = sta_plus;
 		break;
@@ -297,6 +299,7 @@ namespace libdar
 	    case 3:
 	    case 4:
 	    case 5:
+	    case 6:
 		sta.read(f, db_version);
 		last_change[k] = sta;
 		break;
