@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -227,7 +227,7 @@ namespace libdar
 	NLS_SWAP_OUT;
     }
 
-    void database::set_compression(compression algozip)
+    void database::set_compression(compression algozip) const
     {
 	NLS_SWAP_IN;
 	try
@@ -242,6 +242,20 @@ namespace libdar
 	NLS_SWAP_OUT;
     }
 
+        void database::set_compression_level(U_I compr_level) const
+    {
+	NLS_SWAP_IN;
+	try
+	{
+	    pimpl->set_compression_level(compr_level);
+	}
+	catch(...)
+	{
+	    NLS_SWAP_OUT;
+	    throw;
+	}
+	NLS_SWAP_OUT;
+    }
 
     database_archives_list database::get_contents() const
     {
@@ -319,6 +333,25 @@ namespace libdar
 	return ret;
     }
 
+    U_I database::get_compression_level() const
+    {
+	U_I ret;
+
+	NLS_SWAP_IN;
+	try
+	{
+	    ret = pimpl->get_compression_level();
+	}
+	catch(...)
+	{
+	    NLS_SWAP_OUT;
+	    throw;
+	}
+	NLS_SWAP_OUT;
+
+	return ret;
+    }
+
     string database::get_database_version() const
     {
 	string ret;
