@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -56,13 +56,15 @@ extern "C"
 #include "cygwin_adapt.hpp"
 #include "fichier_local.hpp"
 #include "compressor.hpp"
+#include "pile.hpp"
+#include "macro_tools.hpp"
 
 using namespace std;
 
 namespace libdar
 {
 
-    static const unsigned char database_version = 5;
+    static const unsigned char database_version = 6;
 
 #define HEADER_OPTION_NONE 0x00
 #define HEADER_OPTION_COMPRESSOR 0x01
@@ -74,7 +76,7 @@ namespace libdar
     class database_header
     {
     public:
-	database_header() { version = database_version; options = HEADER_OPTION_NONE; algo = compression::gzip; };
+	database_header() { version = database_version; options = HEADER_OPTION_NONE; algo = compression::gzip; compression_level = 9; };
 	database_header(const database_header & ref) = default;
 	database_header(database_header && ref) noexcept = default;
 	database_header & operator = (const database_header & ref) = default;
@@ -84,15 +86,17 @@ namespace libdar
 	void read(generic_file & f);
 	void write(generic_file & f);
 
-	void set_compression(compression algozip);
+	void set_compression(compression algozip, U_I level);
 
 	U_I get_version() const { return version; };
 	compression get_compression() const { return algo; };
+	U_I get_compression_level() const { return compression_level; };
 
     private:
 	unsigned char version;
 	unsigned char options;
 	compression algo;
+	U_I compression_level;
     };
 
     void database_header::read(generic_file & f)
@@ -108,9 +112,19 @@ namespace libdar
 	    char tmp;
 	    f.read(&tmp, 1);
 	    algo = char2compression(tmp);
+	    if(version > 5) // must read the compression level too
+	    {
+		infinint tmp(f); // reading an infinint from f
+
+		compression_level = 0;
+		tmp.unstack(compression_level);
+	    }
 	}
 	else
+	{
 	    algo = compression::gzip; // was the default before choice was available
+	    compression_level = 9;
+	}
     }
 
     void database_header::write(generic_file & f)
@@ -121,13 +135,15 @@ namespace libdar
 	{
 	    char tmp = compression2char(algo);
 	    f.write(&tmp, 1);
+	    infinint(compression_level).dump(f);
 	}
     }
 
-    void database_header::set_compression(compression algozip)
+    void database_header::set_compression(compression algozip, U_I level)
     {
 	algo = algozip;
-	if(algo != compression::gzip)
+	compression_level = level;
+	if(algo != compression::gzip || level != 9)
 	    options |= HEADER_OPTION_COMPRESSOR;
 	else
 	    options &= ~HEADER_OPTION_COMPRESSOR;
@@ -136,81 +152,101 @@ namespace libdar
     generic_file *database_header_create(const shared_ptr<user_interaction> & dialog,
 					 const string & filename,
 					 bool overwrite,
-					 compression algozip)
+					 compression algozip,
+					 U_I compr_level)
     {
-	generic_file *ret = nullptr;
+	pile* stack = new (nothrow) pile();
+	generic_file *tmp = nullptr;
 
 	struct stat buf;
 	database_header h;
-	compressor *comp;
+	proto_compressor *comp;
 
-	if(stat(filename.c_str(), &buf) >= 0 && !overwrite)
-	    throw Erange("database_header_create", gettext("Cannot create database, file exists"));
-	ret = new (nothrow) fichier_local(dialog, filename, gf_write_only, 0666, !overwrite, overwrite, false);
-	if(ret == nullptr)
+	if(stack == nullptr)
 	    throw Ememory("database_header_create");
 
 	try
 	{
-	    h.set_compression(algozip);
-	    h.write(*ret);
 
-	    comp = new (nothrow) compressor(algozip, ret); // upon success, ret is owned by compr
+	    if(stat(filename.c_str(), &buf) >= 0 && !overwrite)
+		throw Erange("database_header_create", gettext("Cannot create database, file exists"));
+	    tmp = new (nothrow) fichier_local(dialog, filename, gf_write_only, 0666, !overwrite, overwrite, false);
+	    if(tmp == nullptr)
+		throw Ememory("database_header_create");
+
+	    stack->push(tmp); // now the fichier_local is managed by stack
+
+	    h.set_compression(algozip, compr_level);
+	    h.write(*stack);
+
+	    comp = macro_tools_build_streaming_compressor(algozip,
+							  *(stack->top()),
+							  compr_level,
+							  2); // using 2 workers at most
 	    if(comp == nullptr)
 		throw Ememory("database_header_create");
-	    else
-		ret = comp;
+
+	    stack->push(comp);
 	}
 	catch(...)
 	{
-	    delete ret;
+	    delete stack;
 	    throw;
 	}
 
-	return ret;
+	return stack;
     }
 
     generic_file *database_header_open(const shared_ptr<user_interaction> & dialog,
 				       const string & filename,
 				       unsigned char & db_version,
-				       compression & algozip)
+				       compression & algozip,
+				       U_I & compr_level)
     {
-	generic_file *ret = nullptr;
+	pile *stack = new (nothrow) pile();
+	generic_file *tmp = nullptr;
+
+	if(stack == nullptr)
+	    throw Ememory("database_header_open");
 
 	try
 	{
 	    database_header h;
-	    compressor *comp;
 
 	    try
 	    {
-		ret = new (nothrow) fichier_local(filename, false);
+		tmp = new (nothrow) fichier_local(filename, false);
 	    }
 	    catch(Erange & e)
 	    {
 		throw Erange("database_header_open", tools_printf(gettext("Error reading database %S : "), &filename) + e.get_message());
 	    }
-	    if(ret == nullptr)
+	    if(tmp == nullptr)
 		throw Ememory("database_header_open");
 
-	    h.read(*ret);
+	    stack->push(tmp);
+
+	    h.read(*stack);
 	    db_version = h.get_version();
 	    algozip = h.get_compression();
+	    compr_level = h.get_compression_level();
 
-	    comp = new (nothrow) compressor(h.get_compression(), ret);
-	    if(comp == nullptr)
+	    tmp = macro_tools_build_streaming_compressor(algozip,
+							 *(stack->top()),
+							 compr_level, // not used for decompression (here)
+							 2); // using 2 workers at most
+	    if(tmp == nullptr)
 		throw Ememory("database_header_open");
-	    else
-		ret = comp;
+
+	    stack->push(tmp);
 	}
 	catch(...)
 	{
-	    if(ret != nullptr)
-		delete ret;
+	    delete stack;
 	    throw;
 	}
 
-	return ret;
+	return stack;
     }
 
     extern const unsigned char database_header_get_supported_version()
