@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file database_header.hpp
@@ -45,12 +45,14 @@ namespace libdar
 	/// \param[in] filename is the file's name to create/overwrite
 	/// \param[in] overwrite set to true to allow file overwriting (else generates an error if file exists)
 	/// \param[in] algozip compression algorithm used for the database
+	/// \param[in] compr_level compression level
 	/// \return the database header has been read and checked the database can now be read from the returned generic_file pointed by the returned value
 	/// then it must be destroyed with the delete operator.
     extern generic_file *database_header_create(const std::shared_ptr<user_interaction> & dialog,
 						const std::string & filename,
 						bool overwrite,
-						compression algozip);
+						compression algozip,
+						U_I compr_level);
 
 	/// read the header of a dar_manager database
 
@@ -58,11 +60,13 @@ namespace libdar
 	/// \param[in] filename is the filename to read from
 	/// \param[out] db_version version of the database
 	/// \param[out] algozip compression algorithm used in the database
+	/// \param[out] compr_level compression level used in the database
 	/// \return the generic_file where the database header has been put
     extern generic_file *database_header_open(const std::shared_ptr<user_interaction> & dialog,
 					      const std::string & filename,
 					      unsigned char & db_version,
-					      compression & algozip);
+					      compression & algozip,
+					      U_I & compr_level);
 
     extern const unsigned char database_header_get_supported_version();
 
