@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -145,10 +145,14 @@ namespace libdar
 
     datetime datetime::loose_diff(const datetime & ref) const
     {
-#if LIBDAR_MICROSECOND_READ_ACCURACY && LIBDAR_MICROSECOND_WRITE_ACCURACY
+#if LIBDAR_TIME_READ_ACCURACY >= LIBDAR_TIME_ACCURACY_NANOSECOND && LIBDAR_TIME_WRITE_ACCURACY >= LIBDAR_TIME_ACCURACY_NANOSECOND
+	static const time_unit max_capa = tu_nanosecond;
+#else
+#if LIBDAR_TIME_READ_ACCURACY >= LIBDAR_TIME_ACCURACY_MICROSECOND && LIBDAR_TIME_WRITE_ACCURACY >= LIBDAR_TIME_ACCURACY_MICROSECOND
 	static const time_unit max_capa = tu_microsecond;
 #else
 	static const time_unit max_capa = tu_second;
+#endif
 #endif
 	datetime ret;
 	infinint aux;
