@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -62,6 +62,7 @@ extern "C"
 #include "integers.hpp"
 #include "erreurs.hpp"
 #include "tools.hpp"
+#include "filesystem_tools.hpp"
 #include "filesystem_specific_attribute.hpp"
 #include "cygwin_adapt.hpp"
 #include "deci.hpp"
@@ -635,6 +636,16 @@ namespace libdar
 		throw;
 	    }
 	    close(fd);
+
+	    datetime linux_birthtime;
+	    if(filesystem_tools_read_linux_birthtime(target, linux_birthtime))
+	    {
+		fsa_time *date_ptr = nullptr;
+		create_or_throw(date_ptr, fsaf_linux_extX, fsan_creation_date, linux_birthtime);
+		fsa.push_back(date_ptr);
+		date_ptr = nullptr;
+	    }
+
 	}
 #else
 	    // nothing to do, as this FSA has not been activated at compilation time
@@ -655,14 +666,18 @@ namespace libdar
 	else
 	{
 	    fsa_time * ptr = nullptr;
-#ifdef LIBDAR_MICROSECOND_READ_ACCURACY
+#if LIBDAR_TIME_READ_ACCURACY == LIBDAR_TIME_ACCURACY_MICROSECOND || LIBDAR_TIME_READ_ACCURACY == LIBDAR_TIME_ACCURACY_NANOSECOND
 	    tools_check_negative_date(tmp.st_birthtim.tv_sec,
 				      ui,
 				      target.c_str(),
 				      "birthtime",
 				      !auto_zeroing_neg_dates,
 				      auto_zeroing_neg_dates);
+#if LIBDAR_TIME_READ_ACCURACY == LIBDAR_TIME_ACCURACY_MICROSECOND
 	    datetime birthtime = datetime(tmp.st_birthtim.tv_sec, tmp.st_birthtim.tv_nsec/1000, datetime::tu_microsecond);
+#else
+	    datetime birthtime = datetime(tmp.st_birthtim.tv_sec, tmp.st_birthtim.tv_nsec, datetime::tu_nanosecond);
+#endif
 	    if(birthtime.is_null()) // assuming an error avoids getting time that way
 		birthtime = datetime(tmp.st_birthtime, 0, datetime::tu_second);
 #else
@@ -743,7 +758,9 @@ namespace libdar
 			case fsan_unset:
 			    throw SRC_BUG;
 			case fsan_creation_date:
-			    throw SRC_BUG; // unknown nature for this family type
+				// note birthtime is not possible to restore under Linux (today),
+				// but can be restored by libdar under BSD systems like MACOS X
+			    break; // nothing to do here, this attribute will be set by tools_make_date()
 			case fsan_append_only:
 			    if(set_immutable)
 				continue;
@@ -1064,12 +1081,14 @@ namespace libdar
 
 	ret = find(fsaf_hfs_plus, fsan_creation_date, tmp);
 #ifndef LIBDAR_BIRTHTIME
+
 	if(ret)
 	    ui.printf(gettext("Birth Time attribute cannot be restored for %s because no FSA familly able to carry that attribute could be activated at compilation time."),
 		      target.c_str());
 	    // here we just warn, the birthtime restoration will be tried (calling twice utime()), even
 	    // if dar has not been compiled with birthtime support. Birthtime support is necessary only to
 	    // read birthtime value of an inode
+	    // birthtime restoration is done by tools_make_date() called from filesystem_tools_make_date()
 #endif
 
 	return ret;
