@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file filesystem_tools.hpp
@@ -96,6 +96,14 @@ namespace libdar
 					       const std::string & source_path,
 					       const std::string & destination_path,
 					       const crc *expected_crc);
+
+
+	/// read the birthtime of target inode
+
+	/// \param[in] target the path the the inode to read the birthtime of
+	/// \param[out] val the birthtime (only valid if the call returned true)
+	/// \return true if the birthtime could be read with linux specific systemcall
+    bool filesystem_tools_read_linux_birthtime(const std::string & target, datetime & val);
 	/// @}
 
 } // end of namespace
