@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -177,7 +177,7 @@ namespace libdar
 	if(terminated)
 	    throw SRC_BUG;
 
-        if(arg.size() > int_tools_maxof_agregate(U_I(0)))
+        if(arg.size() > int_tools_maxof_aggregate(U_I(0)))
             throw SRC_BUG;
 
         write(arg.c_str(), arg.size());
@@ -416,6 +416,17 @@ namespace libdar
 	return ret;
     }
 
+    void generic_file::truncate(const infinint & pos)
+    {
+	if(terminated)
+	    throw SRC_BUG;
+
+	if(rw == gf_write_only || rw == gf_read_write)
+	    inherited_truncate(pos);
+	else
+	    throw Erange("generic_file::truncate", gettext("Cannot truncate a read-only generic_file"));
+    }
+
     void generic_file::sync_write()
     {
 	if(terminated)
