@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file generic_file.hpp
@@ -163,6 +163,25 @@ namespace libdar
 	    /// skip relatively to the current position
         virtual bool skip_relative(S_I x) = 0;
 
+	    /// whether the implementation is able to truncate to the given position
+
+	virtual bool truncatable(const infinint & pos) const = 0;
+
+	    /// truncate file at the given offset
+
+	    /// \param[in] pos is the offset of the where to cut the file, in other word the pos - 1 will be the last byte of the
+	    /// file (if its size is greater than 1). If pos is greater than EOF the implementation should not enlarge the file
+	    /// and may even no skip the file to its current eof. Though this request is not considered an error implementation
+	    /// can thus do nothing when asked to truncate after EOF.
+	    /// \note running this call on a read-only object will always yeld an exception
+	    /// \note if current file position is after the point to truncate, implementation has to skip back the current writing
+	    /// offset to the new end of file.
+	    /// \note implementation of backward skippability and truncate operation should be coherent: If its not possible to
+	    /// skip backward it should not be possible to truncate the file to this position. If truncate a file to requested
+	    /// position is not possible, it should not be possible to skip backward to that position. This truncatable() with the
+	    /// skip_backward direction *should* indicate whether the truncate() action will succeed or generate an exception
+	virtual void truncate(const infinint & pos);
+
 	    /// get the current read/write position
         virtual infinint get_position() const = 0;
 
@@ -272,6 +291,14 @@ namespace libdar
 	    /// \note must either write all data or report an error by throwing an exception
         virtual void inherited_write(const char *a, U_I size) = 0;
 
+	    /// truncate file at the give offset
+
+	    /// \note if pos is greater than the current file size, this call may do nothing (not even enlarging the file)
+	    /// \note this call should always fail on a read-only generic_file
+	    /// \note implementation must throw exception if truncate is not possible for other reason than
+	    /// read/write access mode
+	virtual void inherited_truncate(const infinint & pos) = 0;
+
 
 	    /// write down any pending data
 
