@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -532,6 +532,6 @@ namespace libdar
 	while(working_size > 0 && !finished);
     }
 
-} // end of generic_thread::namespace
+} // end of namespace
 
 
