@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file generic_rsync.hpp
@@ -107,12 +107,14 @@ namespace libdar
 	virtual bool skip(const infinint & pos) override {if(pos != 0 || !initial) throw SRC_BUG; else return true; };
 	virtual bool skip_to_eof() override { throw SRC_BUG; };
 	virtual bool skip_relative(S_I x) override { if(x != 0) throw SRC_BUG; else return true; };
+	virtual bool truncatable(const infinint & pos) const override { return pos == get_position(); };
 	virtual infinint get_position() const override { return x_below->get_position(); };
 
     protected:
 	virtual void inherited_read_ahead(const infinint & amount) override {};
 	virtual U_I inherited_read(char *a, U_I size) override;
 	virtual void inherited_write(const char *a, U_I size) override;
+	virtual void inherited_truncate(const infinint & pos) override { if(pos != get_position()) throw SRC_BUG; };
 	virtual void inherited_sync_write() override {};
 	virtual void inherited_flush_read() override {};
 	virtual void inherited_terminate() override;
