@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file generic_to_global_file.hpp
@@ -68,6 +68,7 @@ namespace libdar
 	virtual bool skip(const infinint & pos) override { return data->skip(pos); };
 	virtual bool skip_to_eof() override { return data->skip_to_eof(); };
 	virtual bool skip_relative(S_I x) override { return data->skip_relative(x); };
+	virtual bool truncatable(const infinint & pos) const override { return data->truncatable(pos); };
 	virtual infinint get_position() const override { return data->get_position(); };
 
 
@@ -81,6 +82,8 @@ namespace libdar
     protected:
 
 	    // virtual method inherited from generic_file
+
+	virtual void inherited_truncate(const infinint & pos) override { data->truncate(pos); };
 	virtual void inherited_read_ahead(const infinint & amount) override {}; // no optimization can be done here, we rely on the OS here
 	virtual void inherited_sync_write() override {};
 	virtual void inherited_flush_read() override {};
