@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -70,6 +70,11 @@ extern "C"
 #include "nls_swap.hpp"
 #include "tools.hpp"
 #include "thread_cancellation.hpp"
+#include "mycurl_easyhandle_node.hpp"
+
+#ifdef LIBTHREADAR_AVAILABLE
+#include "parallel_tronconneuse.hpp"
+#endif
 
 using namespace std;
 
@@ -209,9 +214,32 @@ namespace libdar
 	    }
 	    const curl_version_info_data *cvers = curl_version_info(CURLVERSION_FOURTH);
 	    if(cvers->age < CURLVERSION_FOURTH)
-		throw Erange(gettext("libcurl initialization failed: %s"), "libcurl version not available");
+		throw Erange("libdar_init_libcurl", tools_printf(gettext("libcurl initialization failed: %s"), "libcurl version not available"));
 	    if(cvers->version_num < 0x072600)
-		throw Erange(gettext("libcurl initialization failed: %s"), "libcurl version is too old");
+		throw Erange("libdar_init_libcurl", tools_printf(gettext("libcurl initialization failed: %s"), "libcurl version is too old"));
+
+		// now that libgcrypt is eventually initialized (as well as libcurl, but it does not matter here)
+		// we can initialize the default values for mycurl_easyhandle_node::defaults static field
+
+	    mycurl_easyhandle_node::init_defaults();
+#endif
+
+		// checking libthreadar version
+
+#if LIBTHREADAR_AVAILABLE
+	    unsigned int maj, med, min;
+	    libthreadar::get_version(maj, med, min);
+
+	    if((signed int)maj != atoi(EXPECTED_MAJ_VERSION_THREADAR)
+	       || (signed int)med < atoi(MIN_MED_VERSION_THREADAR)
+	       || ((signed int)med == atoi(MIN_MED_VERSION_THREADAR)
+		   && (signed int)min < atoi(MIN_MIN_VERSION_THREADAR)))
+		throw Erange("libdar_init_libthreadar",
+			     tools_printf(gettext("libthreader version %d.%d.%d is too old, need version %s.%s.%s or more recent"),
+					  maj,med,min,
+					  EXPECTED_MAJ_VERSION_THREADAR,
+					  MIN_MED_VERSION_THREADAR,
+				 	  MIN_MIN_VERSION_THREADAR));
 #endif
 
 	    tools_init();
@@ -224,6 +252,11 @@ namespace libdar
 
     extern void close_and_clean()
     {
+#ifdef LIBCURL_AVAILABLE
+	    // mycurl_easyhandle_node::efaults static field, may contain secu_string that rely on libgcrypt secured memory
+	mycurl_easyhandle_node::release_defaults();
+	    // it must thus be released before released libgcrypt below
+#endif
 #ifdef CRYPTO_AVAILABLE
 	if(libdar_initialized_gcrypt)
 	    gcry_control(GCRYCTL_TERM_SECMEM, 0); // by precaution if not already done by libgcrypt itself
