@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file hash_fichier.hpp
@@ -101,6 +101,7 @@ namespace libdar
         virtual bool skip(const infinint & pos) override {if(ref == nullptr || pos != ref->get_position()) throw SRC_BUG; else return true; };
         virtual bool skip_to_eof() override { if(get_mode() == gf_write_only) return true; else throw SRC_BUG; };
         virtual bool skip_relative(S_I x) override { if(x != 0) throw SRC_BUG; else return true; };
+	virtual bool truncatable(const infinint & pos) const override { return false; };
 	virtual infinint get_position() const override { if(ref == nullptr) throw SRC_BUG; return ref->get_position(); };
 
 	    /// for debugging purposes only
@@ -113,6 +114,7 @@ namespace libdar
  	virtual bool fichier_global_inherited_read(char *a, U_I size, U_I & read, std::string & message) override;
 
 	    // inherited from generic_file
+	virtual void inherited_truncate(const infinint & pos) override { throw SRC_BUG; }; // truncate not supported on hash files
 	virtual void inherited_sync_write() override {};
 	virtual void inherited_flush_read() override {};
 	virtual void inherited_terminate() override;
