@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -33,6 +33,8 @@ extern "C"
 #include "integers.hpp"
 #include "tools.hpp"
 #include "deci.hpp"
+#include "header_flags.hpp"
+
 
 #define LIBDAR_URL_VERSION "http://dar.linux.free.fr/pre-release/doc/Notes.html#Dar_version_naming"
 
@@ -40,8 +42,32 @@ using namespace std;
 
 namespace libdar
 {
+
+    	    // FLAG VALUES
+
+	    // flags of the historical bytes (oldest), read/wrote last (or alone if no extra bits are set)
+    static constexpr U_I FLAG_SAVED_EA_ROOT = 0x80;       ///< no more used since version "05"
+    static constexpr U_I FLAG_SAVED_EA_USER = 0x40;       ///< no more used since version "05"
+    static constexpr U_I FLAG_SCRAMBLED     = 0x20;       ///< scrambled or strong encryption used
+    static constexpr U_I FLAG_SEQUENCE_MARK = 0x10;       ///< escape sequence marks present for sequential reading
+    static constexpr U_I FLAG_INITIAL_OFFSET = 0x08;      ///< whether the header contains the initial offset (size of clear data before encrypted)
+    static constexpr U_I FLAG_HAS_CRYPTED_KEY = 0x04;     ///< the header contains a symmetrical key encrypted with asymmetrical algorithm
+    static constexpr U_I FLAG_HAS_REF_SLICING = 0x02;     ///< the header contains the slicing information of the archive of reference (used for isolated catalogue)
+    static constexpr U_I FLAG_IS_RESERVED_1 = 0x01;       ///< this flag is reserved meaning two bytes length bitfield
+    static constexpr U_I FLAG_IS_RESERVED_2 = 0x0100;     ///< reserved for future use
+    static constexpr U_I FLAG_ARCHIVE_IS_SIGNED = 0x0200; ///< archive is signed
+    static constexpr U_I FLAG_HAS_KDF_PARAM = 0x0400;     ///< archive header contains salt and non default interaction count
+    static constexpr U_I FLAG_HAS_COMPRESS_BS = 0x0800;   ///< archive header contains a compression block size (else it is assumed equal to zero)
+	// when adding a new flag, all_flags_known() must be updated to pass sanity checks
+
     static const U_I HEADER_CRC_SIZE = 2; //< CRC width (deprecated, now only used when reading old archives)
 
+	// check we are not facing a more recent format than what we know, this would fail CRC calculation before reporting the real reason of the issue
+    static bool all_flags_known(header_flags flag);
+
+	//
+
+
     header_version::header_version()
     {
 	algo_zip = compression::none;
@@ -55,13 +81,15 @@ namespace libdar
 	iteration_count = PRE_FORMAT_10_ITERATION;
 	kdf_hash = hash_algo::sha1; // used by default
 	salt = "";
+	compr_bs = 0;
+	has_kdf_params = false;
     }
 
     void header_version::read(generic_file & f, user_interaction & dialog, bool lax_mode)
     {
 	crc *ctrl = nullptr;
 	char tmp;
-        U_I flag;
+        header_flags flag;
 
 	f.reset_crc(HEADER_CRC_SIZE);
 	try
@@ -116,20 +144,54 @@ namespace libdar
 		}
 		catch(Erange & e)
 		{
+		    bool loop = false;
+
 		    if(!lax_mode)
 			throw;
 
-		    string answ = dialog.get_string(gettext("LAX MODE: Unknown compression algorithm used, assuming data corruption occurred. Please help me, answering with one of the following words \"none\", \"gzip\", \"bzip2\", \"lzo\" or \"xz\" at the next prompt:"), true);
-		    if(answ == gettext("none"))
-			tmp = compression2char(compression::none);
-		    else if(answ == gettext("gzip"))
-			tmp = compression2char(compression::gzip);
-		    else if(answ == gettext("bzip2"))
-			tmp = compression2char(compression::bzip2);
-		    else if(answ == gettext("lzo"))
-			tmp = compression2char(compression::lzo);
-		    else if(answ == gettext("xz"))
-			tmp = compression2char(compression::xz);
+		    do
+		    {
+		    string answ = dialog.get_string(gettext("LAX MODE: Unknown compression algorithm used, assuming data corruption occurred. Please help me, answering with one of the following words \"none\", \"gzip\", \"bzip2\", \"lzo\", \"xz\", \"zstd\" or \"lz4\" at the next prompt:"), true);
+
+			if(answ == gettext("none"))
+			{
+			    tmp = compression2char(compression::none);
+			    loop = false;
+			}
+			else if(answ == gettext("gzip"))
+			{
+			    tmp = compression2char(compression::gzip);
+			    loop = false;
+			}
+			else if(answ == gettext("bzip2"))
+			{
+			    tmp = compression2char(compression::bzip2);
+			    loop = false;
+			}
+			else if(answ == gettext("lzo"))
+			{
+			    tmp = compression2char(compression::lzo);
+			    loop = false;
+			}
+			else if(answ == gettext("xz"))
+			{
+			    tmp = compression2char(compression::xz);
+			    loop = false;
+			}
+			else if(answ == gettext("zstd"))
+			{
+			    tmp = compression2char(compression::zstd);
+			    loop = false;
+			}
+			else if(answ == gettext("lz4"))
+			{
+			    tmp = compression2char(compression::lz4);
+			    loop = false;
+			}
+			else
+			    loop = true;
+		    }
+		    while(loop);
 		}
 	    }
 	    while(!ok);
@@ -140,33 +202,18 @@ namespace libdar
 	tools_read_string(f, cmd_line);
 
 	if(edition > 1)
-	{
-	    unsigned char tomp;
-	    if(f.read((char *)&tomp, 1) != 1)
-		throw Erange("header_version::read", gettext("Reached End of File while reading archive header_version data structure"));
-		// even in lax mode, because reading further is vain
-	    flag = tomp;
-	}
+	    flag.read(f);
 	else
-	    flag = 0; // flag has been at edition 2
-	if((flag & FLAG_HAS_AN_EXTENDED_SIZE) != 0)
-	{
-	    unsigned char tomp;
+	    flag.clear(); // flag has been at edition 2
 
-	    if(f.read((char *)&tomp, 1) != 1)
-		throw Erange("header_version::read", gettext("Reached End of File while reading archive header_version data structure"));
-	    flag <<= 8;
-	    flag += tomp;
-	}
-
-	if((flag & FLAG_INITIAL_OFFSET) != 0)
+	if(flag.is_set(FLAG_INITIAL_OFFSET))
 	{
 	    initial_offset.read(f);
 	}
 	else
 	    initial_offset = 0;
 
-	if((flag & FLAG_SCRAMBLED) != 0)
+	if(flag.is_set(FLAG_SCRAMBLED))
 	{
 	    ciphered = true;
 	    if(edition >= 9)
@@ -199,7 +246,7 @@ namespace libdar
 	    sym = crypto_algo::none; // no crypto used, coherent with flag
 	}
 
-	has_tape_marks = (flag & FLAG_SEQUENCE_MARK) != 0;
+	has_tape_marks = flag.is_set(FLAG_SEQUENCE_MARK);
 	if(edition < 8 && has_tape_marks)
 	{
 	    if(lax_mode)
@@ -214,7 +261,7 @@ namespace libdar
 	    crypted_key = nullptr;
 	}
 
-	if((flag & FLAG_HAS_CRYPTED_KEY) != 0)
+	if(flag.is_set(FLAG_HAS_CRYPTED_KEY))
 	{
 	    infinint key_size = f; // reading key_size from the header_version in archive
 
@@ -225,7 +272,7 @@ namespace libdar
 		throw Erange("header_version::read", gettext("Missing data for encrypted symmetrical key"));
 	}
 
-	if((flag & FLAG_HAS_REF_SLICING) != 0)
+	if(flag.is_set(FLAG_HAS_REF_SLICING))
 	{
 	    try
 	    {
@@ -249,13 +296,14 @@ namespace libdar
 	else
 	    clear_slice_layout();
 
-	arch_signed = (flag & FLAG_ARCHIVE_IS_SIGNED) != 0;
+	arch_signed = flag.is_set(FLAG_ARCHIVE_IS_SIGNED);
 
-	if((flag & FLAG_HAS_KDF_PARAM) != 0)
+	if(flag.is_set(FLAG_HAS_KDF_PARAM))
 	{
 	    unsigned char tmp_hash;
 	    infinint salt_size(f); // reading salt_size from file
 
+	    has_kdf_params = true;
 	    tools_read_string_size(f, salt, salt_size);
 	    iteration_count.read(f);
 	    f.read((char *)&tmp_hash, 1);
@@ -316,6 +364,11 @@ namespace libdar
 	    kdf_hash = hash_algo::sha1;
 	}
 
+	if(flag.is_set(FLAG_HAS_COMPRESS_BS))
+	    compr_bs.read(f);
+	else
+	    compr_bs = 0;
+
 	ctrl = f.get_crc();
 	if(ctrl == nullptr)
 	    throw SRC_BUG;
@@ -392,27 +445,24 @@ namespace libdar
     {
 	crc *ctrl = nullptr;
 	char tmp;
-        unsigned char flag[2];
+        header_flags flag;
 
 	    // preparing the data
 
-	flag[0] = 0;
-	flag[1] = 0;
-
 	if(!initial_offset.is_zero())
-	    flag[0] |= FLAG_INITIAL_OFFSET; // adding it to the flag
+	    flag.set_bits(FLAG_INITIAL_OFFSET); // adding it to the flag
 
 	if(crypted_key != nullptr)
-	    flag[0] |= FLAG_HAS_CRYPTED_KEY;
+	    flag.set_bits(FLAG_HAS_CRYPTED_KEY);
 
 	if(ref_layout != nullptr)
-	    flag[0] |= FLAG_HAS_REF_SLICING;
+	    flag.set_bits(FLAG_HAS_REF_SLICING);
 
 	if(has_tape_marks)
-	    flag[0] |= FLAG_SEQUENCE_MARK;
+	    flag.set_bits(FLAG_SEQUENCE_MARK);
 
 	if(sym != crypto_algo::none)
-	    flag[0] |= FLAG_SCRAMBLED;
+	    flag.set_bits(FLAG_SCRAMBLED);
 	    // Note: we cannot set this flag (even if ciphered is true) if we do not know the crypto algo
 	    // as since version 9 the presence of this flag implies the existence
 	    // of the crypto algorithm in the header/trailer and we will always
@@ -420,16 +470,15 @@ namespace libdar
 	    // equal to 9).
 
 	if(arch_signed)
-	    flag[1] |= (FLAG_ARCHIVE_IS_SIGNED >> 8);
+	    flag.set_bits(FLAG_ARCHIVE_IS_SIGNED);
 
 	if(salt.size() > 0)
-	    flag[1] |= (FLAG_HAS_KDF_PARAM >> 8);
+	    flag.set_bits(FLAG_HAS_KDF_PARAM);
 
-	if(flag[1] > 0)
-	    flag[1] |= FLAG_HAS_AN_EXTENDED_SIZE;
-	    // and we will drop two bytes for the flag
+	if(compr_bs > 0)
+	    flag.set_bits(FLAG_HAS_COMPRESS_BS);
 
-	if(!all_flags_known( ( (U_I)(flag[1]) << 8 ) + flag[0]))
+	if(!all_flags_known(flag))
 	    throw SRC_BUG; // all_flag_known has not been updated with new flags
 
 	    // writing down the data
@@ -439,9 +488,7 @@ namespace libdar
 	tmp = compression2char(algo_zip);
 	f.write(&tmp, sizeof(tmp));
 	tools_write_string(f, cmd_line);
-	if(flag[1] != 0)
-	    f.write((char *)&(flag[1]), sizeof(unsigned char));
-	f.write((char *)&(flag[0]), sizeof(unsigned char));
+	flag.dump(f);
 	if(initial_offset != 0)
 	    initial_offset.dump(f);
 	if(sym != crypto_algo::none)
@@ -471,6 +518,9 @@ namespace libdar
 	    f.write((char *)&tmp_hash, 1);
 	}
 
+	if(compr_bs > 0)
+	    compr_bs.dump(f);
+
 	ctrl = f.get_crc();
 	if(ctrl == nullptr)
 	    throw SRC_BUG;
@@ -493,6 +543,7 @@ namespace libdar
 	if(algo == hash_algo::none)
 	    throw Erange("header_version::set_kdf_hash", gettext("invalid hash algorithm provided for key derivation function"));
 	kdf_hash = algo;
+	has_kdf_params = true;
     }
 
     string header_version::get_sym_crypto_name() const
@@ -523,17 +574,17 @@ namespace libdar
 
 	dialog.printf(gettext("Archive version format               : %s"), get_edition().display().c_str());
 	dialog.printf(gettext("Compression algorithm used           : %S"), &algo);
+	dialog.printf(gettext("Compression block size used          : %i"), &compr_bs);
 	dialog.printf(gettext("Symmetric key encryption used        : %S"), &sym_str);
 	dialog.printf(gettext("Asymmetric key encryption used       : %S"), &asym);
 	dialog.printf(gettext("Archive is signed                    : %S"), &xsigned);
 	dialog.printf(gettext("Sequential reading marks             : %s"), (get_tape_marks() ? gettext("present") : gettext("absent")));
 	dialog.printf(gettext("User comment                         : %S"), &(get_command_line()));
-	if(ciphered && sym != crypto_algo::scrambling)
+	if(has_kdf_params)
 	{
 	    dialog.printf(gettext("KDF iteration count                  : %S"), &kdf_iter);
 	    dialog.printf(gettext("KDF hash algorithm                   : %S"), &hashing);
-	    if(salt.size() > 0)
-		dialog.printf(gettext("Salt size                            : %d byte%c"), salt.size(), salt.size() > 1 ? 's' : ' ');
+	    dialog.printf(gettext("Salt size                            : %d byte%c"), salt.size(), salt.size() > 1 ? 's' : ' ');
 	}
     }
 
@@ -551,6 +602,7 @@ namespace libdar
 	arch_signed = false;
 	iteration_count = PRE_FORMAT_10_ITERATION;
 	kdf_hash = hash_algo::sha1;
+	compr_bs = 0;
     }
 
     void header_version::copy_from(const header_version & ref)
@@ -579,9 +631,11 @@ namespace libdar
 	has_tape_marks = ref.has_tape_marks;
 	ciphered = ref.ciphered;
 	arch_signed = ref.arch_signed;
+	has_kdf_params = ref.has_kdf_params;
 	salt = ref.salt;
 	iteration_count = ref.iteration_count;
 	kdf_hash = ref.kdf_hash;
+	compr_bs = ref.compr_bs;
     }
 
     void header_version::move_from(header_version && ref) noexcept
@@ -596,9 +650,11 @@ namespace libdar
 	has_tape_marks = move(ref.has_tape_marks);
 	ciphered = move(ref.ciphered);
 	arch_signed = move(ref.arch_signed);
+	has_kdf_params = move(ref.has_kdf_params);
 	salt = move(ref.salt);
 	iteration_count = move(ref.iteration_count);
 	kdf_hash = move(ref.kdf_hash);
+	compr_bs = move(ref.compr_bs);
     }
 
     void header_version::detruit()
@@ -607,20 +663,23 @@ namespace libdar
 	clear_slice_layout();
     }
 
-
-    bool header_version::all_flags_known(U_I flag)
+    static bool all_flags_known(header_flags flag)
     {
-	flag &= ~FLAG_SAVED_EA_ROOT;
-	flag &= ~FLAG_SAVED_EA_USER;
-	flag &= ~FLAG_SCRAMBLED;
-	flag &= ~FLAG_SEQUENCE_MARK;
-	flag &= ~FLAG_INITIAL_OFFSET;
-	flag &= ~FLAG_HAS_CRYPTED_KEY;
-	flag &= ~FLAG_HAS_REF_SLICING;
-	flag &= ~(FLAG_HAS_AN_EXTENDED_SIZE << 8);
-	flag &= ~FLAG_ARCHIVE_IS_SIGNED;
-	flag &= ~FLAG_HAS_KDF_PARAM;
-	return flag == 0;
+	U_I bf = 0;
+
+	bf |= FLAG_SAVED_EA_ROOT;
+	bf |= FLAG_SAVED_EA_USER;
+	bf |= FLAG_SCRAMBLED;
+	bf |= FLAG_SEQUENCE_MARK;
+	bf |= FLAG_INITIAL_OFFSET;
+	bf |= FLAG_HAS_CRYPTED_KEY;
+	bf |= FLAG_HAS_REF_SLICING;
+	bf |= FLAG_ARCHIVE_IS_SIGNED;
+	bf |= FLAG_HAS_KDF_PARAM;
+	bf |= FLAG_HAS_COMPRESS_BS;
+	flag.unset_bits(bf);
+
+	return flag.is_all_cleared();
     }
 
 } // end of namespace
