@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file header_version.hpp
@@ -79,10 +79,12 @@ namespace libdar
 	void set_tape_marks(bool presence) { has_tape_marks = presence; };
 	void set_signed(bool is_signed) { arch_signed = is_signed; };
 
-	void set_salt(const std::string & arg) { salt = arg; };
-	void set_iteration_count(const infinint & arg) { iteration_count = arg; };
+	void set_salt(const std::string & arg) { salt = arg; has_kdf_params = true; };
+	void set_iteration_count(const infinint & arg) { iteration_count = arg; has_kdf_params = true; };
 	void set_kdf_hash(hash_algo algo);
 
+	void set_compression_block_size(const infinint & bs) { compr_bs = bs; };
+
 	    // gettings
 
 	const archive_version & get_edition() const { return edition; };
@@ -101,6 +103,7 @@ namespace libdar
 	const std::string & get_salt() const { return salt; };
 	const infinint & get_iteration_count() const { return iteration_count; };
 	hash_algo get_kdf_hash() const { return kdf_hash; };
+	const infinint & get_compression_block_size() const { return compr_bs; };
 
 	    // display
 
@@ -123,43 +126,20 @@ namespace libdar
 
 	bool ciphered;           ///< whether the archive is ciphered, even if we do not know its crypto algorithm (old archives)
 	bool arch_signed;        ///< whether the archive is signed
+	bool has_kdf_params;     ///< has salt/ineration/kdf_hash fields valid
 	std::string salt;        ///< used for key derivation
 	infinint iteration_count;///< used for key derivation
 	hash_algo kdf_hash;      ///< used for key derivation
+	infinint compr_bs;       ///< the compression block size (0 for legacy compression mode)
 
 	void nullifyptr() noexcept { crypted_key = nullptr; ref_layout = nullptr; };
 	void copy_from(const header_version & ref);
 	void move_from(header_version && ref) noexcept;
 	void detruit();
 
-	    // FLAG VALUES
-
-	    // flags of the historical bytes (oldest), read/wrote last (or alone if no extra bits are set)
-	static constexpr U_I FLAG_SAVED_EA_ROOT = 0x80;      ///< no more used since version "05"
-	static constexpr U_I FLAG_SAVED_EA_USER = 0x40;      ///< no more used since version "05"
-	static constexpr U_I FLAG_SCRAMBLED     = 0x20;      ///< scrambled or strong encryption used
-	static constexpr U_I FLAG_SEQUENCE_MARK = 0x10;      ///< escape sequence marks present for sequential reading
-	static constexpr U_I FLAG_INITIAL_OFFSET = 0x08;     ///< whether the header contains the initial offset (size of clear data before encrypted) NOTE : This value is set internally by header_version, no need to set flag with it! But that's OK to set it or not, it will be updated according to initial_offset's value.
-	static constexpr U_I FLAG_HAS_CRYPTED_KEY = 0x04;    ///< the header contains a symmetrical key encrypted with asymmetrical algorithm
-	static constexpr U_I FLAG_HAS_REF_SLICING = 0x02;    ///< the header contains the slicing information of the archive of reference (used for isolated catalogue)
-
-	    // if flag is two bytes long, the first byte read/wrote has this bit set
-	static constexpr U_I FLAG_HAS_AN_EXTENDED_SIZE = 0x01; ///< the flag is two bytes length
-
-	    // flags of the new byte (read/wrote before the historical byte)
-	static constexpr U_I FLAG_ARCHIVE_IS_SIGNED = 0x0200; ///< archive is signed
-	static constexpr U_I FLAG_HAS_KDF_PARAM = 0x0400;     ///< archive header contains salt and non default interaction count
-
-	    // if the flag is three or more bytes long, these bits are set in the first and second bytes
-	static constexpr U_I FLAG_HAS_AN_SECOND_EXTENDED_SIZE = 0x0101; ///< reserved for future use
-
-	    //
 
 	static constexpr U_I PRE_FORMAT_10_ITERATION = 2000;   ///< fixed value used for key derivation before archive format 10
 
-	    // check we are not facing a more recent format than what we know, this would fail CRC calculation before reporting the real reason of the issue
-	static bool all_flags_known(U_I flag);
-
     };
 
 } // end of namespace
