@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file i_archive.hpp
@@ -245,6 +245,7 @@ namespace libdar
 				bool empty_dir,
 				compression algo,
 				U_I compression_level,
+				U_I compression_block_size,
 				const infinint & file_size,
 				const infinint & first_file_size,
 				const mask & ea_mask,
@@ -262,7 +263,7 @@ namespace libdar
 				bool empty,
 				bool alter_atime,
 				bool furtive_read_mode,
-				bool same_fs,
+				const filesystem_ids & same_fs,
 				comparison_fields what_to_check,
 				bool snapshot,
 				bool cache_directory_tagging,
@@ -280,7 +281,8 @@ namespace libdar
 				const mask & backup_hook_file_mask,
 				bool ignore_unknown,
 				const fsa_scope & scope,
-				bool multi_threaded,
+				U_I multi_threaded_crypto,
+				U_I multi_threaded_compress,
 				bool delta_signature,
 				bool build_delta_sig,
 				const mask & delta_mask,
@@ -316,6 +318,7 @@ namespace libdar
 			      bool empty_dir,                   ///< whether to store excluded dir as empty directories
 			      compression algo,                 ///< compression algorithm
 			      U_I compression_level,            ///< compression level (range 1 to 9)
+			      U_I compression_block_size,       ///< compression block size (0 for normal/legacy compression mode)
 			      const infinint & file_size,       ///< slice size
 			      const infinint & first_file_size, ///< first slice size
 			      const mask & ea_mask,             ///< Extended Attribute to consider
@@ -333,7 +336,7 @@ namespace libdar
 			      bool empty,                       ///< whether to make an "dry-run" execution
 			      bool alter_atime,                 ///< whether to alter atime date (by opposition to ctime) when reading files
 			      bool furtive_read_mode,           ///< whether to neither alter atime nor ctome (if true alter_atime is ignored)
-			      bool same_fs,                     ///< confin the files consideration to a single filesystem
+			      const filesystem_ids & same_fs,   ///< confin the files consideration to the given set of filesystem
 			      comparison_fields what_to_check,  ///< fields to consider wien comparing inodes (see comparison_fields enumeration)
 			      bool snapshot,                    ///< make as if all file had not changed
 			      bool cache_directory_tagging,     ///< avoid saving directory which follow the cache directory tagging
@@ -353,7 +356,8 @@ namespace libdar
 			      const mask & backup_hook_file_mask,         ///< files elected to have a command executed before and after their backup
 			      bool ignore_unknown,                        ///< whether to warn when an unknown inode type is met
 			      const fsa_scope & scope,                    ///< FSA scope for the operation
-			      bool multi_threaded,              ///< whether libdar is allowed to spawn several thread to possibily work faster on multicore CPU
+			      U_I multi_threaded_crypto,        ///< whether libdar is allowed to spawn several thread to possibily work faster on multicore CPU
+			      U_I multi_threaded_compress,      ///< neeed compression_block_size > 0 to use several threads for compression/decompression
 			      bool delta_signature,             ///< whether to calculate and store binary delta signature for each saved file
 			      bool build_delta_sig,             ///< whether to rebuild delta sig accordingly to delta_mask
 			      const mask & delta_mask,          ///< which files to consider delta signature for
