@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -69,6 +69,7 @@ namespace libdar
 	check_order_asked = true;
 	cur_db_version = database_header_get_supported_version();
 	algo = compression::gzip;   // stays the default algorithm for new databases
+	compr_level = 9; // stays the default compression level for new databases
     }
 
     database::i_database::i_database(const shared_ptr<user_interaction> & dialog, const string & base, const database_open_options & opt): mem_ui(dialog)
@@ -76,7 +77,8 @@ namespace libdar
 	generic_file *f = database_header_open(dialog,
 					       base,
 					       cur_db_version,
-					       algo);
+					       algo,
+					       compr_level);
 
 	if(f == nullptr)
 	    throw Ememory("database::i_database::database");
@@ -165,7 +167,7 @@ namespace libdar
     }
 
     void database::i_database::dump(const std::string & filename,
-			const database_dump_options & opt) const
+				    const database_dump_options & opt) const
     {
 	if(files == nullptr && data_files == nullptr)
 	    throw Erange("database::i_database::dump", gettext("Cannot write down a read-only database"));
@@ -173,7 +175,8 @@ namespace libdar
 	generic_file *f = database_header_create(get_pointer(),
 						 filename,
 						 opt.get_overwrite(),
-						 algo);
+						 algo,
+						 compr_level);
 	if(f == nullptr)
 	    throw Ememory("database::i_database::dump");
 
