@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file i_entrepot_libcurl.hpp
@@ -108,7 +108,7 @@ namespace libdar
 	std::string reading_dir_tmp;
 	U_I wait_delay;
 
-	void set_libcurl_URL();
+	std::string get_libcurl_URL() const;
 	void set_libcurl_authentication(user_interaction & dialog,         ///< for user interaction
 					const std::string & location,      ///< server to authenticate with
 					const std::string & login,         ///< login to use
