@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file macro_tools.hpp
@@ -49,7 +49,7 @@ extern "C"
 #include "slice_layout.hpp"
 #include "tuyau.hpp"
 #include "trivial_sar.hpp"
-
+#include "proto_compressor.hpp"
 
 
 #define BUFFER_SIZE 102400
@@ -88,22 +88,18 @@ namespace libdar
 
 	/// \note the stack has the following contents depending on given options
 	///
-	/// +-top                                           LIBDAR_STACK_LABEL_
-	/// +----------------------------------------------+---------------------+
-	/// | [ generic_thread ]                           |_UNCOMPRESSED        |
-	/// | compressor                                   |v    v    v          |
-	/// +----------------------------------------------+---------------------+
-	/// | [ generic_thread ]                           |_CLEAR               |
-	/// | [ escape ]                                   |v   v   v            |
-	/// +----------------------------------------------+v---v---v------------+
-	/// | [ generic_thread ]                           |_UNCYPHERED          |
-	/// | [ cache ]  |  crypto_sym  |  scrambler       |v   v   v            |
-	/// | [ tronc ]                                    |LEVEL 1              |
-	/// | trivial_sar  |  zapette  |  sar              |v   v   v            |
-	/// +----------------------------------------------+---------------------+
+	/// +-top                                                     LIBDAR_STACK_LABEL_
+	/// +-------------------------------------------------------+---------------------+
+	/// | compressor                                            |v   v   v            |
+	/// +-------------------------------------------------------+---------------------+
+	/// | [ escape ]                                            |v   v   v            |
+	/// +-------------------------------------------------------+v---v---v------------+
+	/// | [ cache ]  | (parallel_)tronconneuse | scrambler      |v   v   v            |
+	/// | [ tronc ]                                             |LEVEL 1              |
+	/// | trivial_sar  |  zapette  |  sar                       |v   v   v            |
+	/// +-------------------------------------------------------+---------------------+
 	/// +-bottom
 	///
-	/// \note generic_thread objects are only present in the stack if multi-thread is active
 	/// \note escape is present unless tape mark have been disabled at archive creation time
 	/// \note tronc is not present in sequential read mode
 	/// \note cache layer is present only in absence of encryption and when no escape layer is above
@@ -131,7 +127,8 @@ namespace libdar
 					 bool info_details,    ///< be or not verbose about the archive openning
 					 std::list<signator> & gnupg_signed, ///< list of existing signature found for that archive (valid or not)
 					 slice_layout & sl,    ///< slicing layout of the archive
-					 bool multi_threaded,  ///< true if several thread shall be run concurrently by libdar
+					 U_I multi_threaded_crypto,  ///< number of worker thread to run for cryptography (1 -> tronconneuse object, more -> parallel_tronconneuse object)
+					 U_I multi_threaded_compress,  ///< number of worker threads to compress/decompress (need compression_block_size > 0)
 					 bool header_only      ///< if true, stop the process before openning the encryption layer
 	);
         // all allocated objects (ret1, ret2, scram), must be deleted when no more needed by the caller of this routine
@@ -194,6 +191,7 @@ namespace libdar
 	/// \param[in]  pause how many slices to wait before pausing (0 to never wait)
 	/// \param[in]  algo compression algorithm
 	/// \param[in]  compression_level compression level
+	/// \param[in]  compression_block_size if set to zero use streaming compression else use block compression of the given size
 	/// \param[in]  file_size size of the slices
 	/// \param[in]  first_file_size size of the first slice
 	/// \param[in]  execute command to execute after each slice creation
@@ -212,23 +210,21 @@ namespace libdar
 	/// \param[in]  data_name to use in slice header
 	/// \param[in]  iteration_count used for key derivation when passphrase is human provided
 	/// \param[in]  kdf_hash hash algorithm used for the key derivation function
-	/// \param[in]  multi_threaded true if libdar can spawn several thread to work
+	/// \param[in]  multi_threaded_crypto number of worker threads to handle cryptography stuff
+	/// \param[in]  multi_threaded_compress number of worker threads to handle compression (block mode only)
 	///
 	/// \note the stack has the following contents depending on given options
 	///
-	/// +-top                                          LIBDAR_STACK_LABEL_
-	/// +----------------------------------------------+---------------------+
-	/// | [ generic_thread ]                           |                     |
-	/// | compressor                                   |                     |
-	/// +----------------------------------------------+---------------------+
-	/// | [ generic_thread ]                           |                     |
-	/// | [ escape ]                                   |                     |
-	/// +-- - - - - - - - - - - - - - - - - - - - - - -+---------------------+
-	/// | [ generic_thread (if crypt or scam is used) ]|                     |
-	/// | cache  |  crypto_sym  |  scrambler           |                     |
-	/// | [ cache ]                                    |_CACHE_PIPE          |
-	/// | trivial_sar  |  null_file  |  sar            |                     |
-	/// +----------------------------------------------+---------------------+
+	/// +-top                                                       LIBDAR_STACK_LABEL_
+	/// +---------------------------------------------------------+---------------------+
+	/// | compressor                                              |                     |
+	/// +---------------------------------------------------------+---------------------+
+	/// | [ escape ]                                              |                     |
+	/// +-- - - - - - - - - - - - - - - - - - - - - - - - - - - - +---------------------+
+	/// | cache  |  (paralle_)tronconneuse |  scrambler           |                     |
+	/// | [ cache ]                                               |_CACHE_PIPE          |
+	/// | trivial_sar  |  null_file  |  sar                       |                     |
+	/// +---------------------------------------------------------+---------------------+
 	/// +-bottom
 	///
 	/// \note the bottom cache layer is only present when trivial_sar is used to write on a pipe.
@@ -253,6 +249,7 @@ namespace libdar
 					  const infinint & pause,
 					  compression algo,
 					  U_I compression_level,
+					  U_I compression_block_size,
 					  const infinint & file_size,
 					  const infinint & first_file_size,
 					  const std::string & execute,
@@ -271,7 +268,8 @@ namespace libdar
 					  const label & data_name,
 					  const infinint & iteration_count,
 					  hash_algo kdf_hash,
-					  bool multi_threaded);
+					  U_I multi_threaded_crypto,
+					  U_I multi_threaded_compress);
 
 	/// dumps the catalogue and close all the archive layers to terminate the archive
 
@@ -319,6 +317,30 @@ namespace libdar
 				       tuyau *&in,
 				       tuyau *&out);
 
+	/// return a proto_compressor object realizing the desired (de)compression level/aglo on top of "base" in streaming mode
+
+	/// \param[in] algo the compression algorithm to use
+	/// \param[in,out] base the layer to read from or write to compressed data
+	/// \param[in] compression_level the compression level to use (when compressing data)
+	/// \param[in] num_workers for the few algorithm that allow multi-thread compression (lz4 actually)
+    extern proto_compressor* macro_tools_build_streaming_compressor(compression algo,
+								    generic_file & base,
+								    U_I compression_level,
+								    U_I num_workers);
+
+	/// return a proto_compressor object realizing the desired (de)compression level/algo on to of "base" in block mode
+
+	/// \param[in] algo the compression algorithm to use
+	/// \param[in,out] base the layer to read from or write to compressed data
+	/// \param[in] compression_level the compression level to use (when compressing data)
+	/// \param[in] num_workers for the few algorithm that allow multi-thread compression (lz4 actually)
+	/// \param[in] block_size size of the data block
+    extern proto_compressor* macro_tools_build_block_compressor(compression algo,
+								generic_file & base,
+								U_I compression_level,
+								U_I num_workers,
+								U_I block_size);
+
         /// @}
 
 } // end of namespace
