@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -121,4 +121,11 @@ namespace libdar
 	position += size - ret;
     }
 
+    void memory_file::inherited_truncate(const infinint & pos)
+    {
+	data.truncate(pos);
+	if(position > pos)
+	    position = pos;
+    }
+
 }  // end of namespace
