@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file memory_file.hpp
@@ -60,6 +60,7 @@ namespace libdar
 	virtual bool skip(const infinint & pos) override;
 	virtual bool skip_to_eof() override;
 	virtual bool skip_relative(S_I x) override;
+	virtual bool truncatable(const infinint & pos) const override { return true; };
 	virtual infinint get_position() const  override { if(is_terminated()) throw SRC_BUG; return position; };
 
 
@@ -69,6 +70,7 @@ namespace libdar
 	virtual void inherited_read_ahead(const infinint & amount) override {}; // no optimization can be done here, we rely on the OS here
 	virtual U_I inherited_read(char *a, U_I size) override;
 	virtual void inherited_write(const char *a, U_I size) override;
+	virtual void inherited_truncate(const infinint & pos) override;
 	virtual void inherited_sync_write() override {};
 	virtual void inherited_flush_read() override {};
 	virtual void inherited_terminate() override {};
