@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file null_file.hpp
@@ -60,6 +60,7 @@ namespace libdar
         virtual bool skip(const infinint &pos) override { set_offset(pos); return true; };
         virtual bool skip_to_eof() override { offset = max_offset; return true; };
         virtual bool skip_relative(signed int x) override { return set_rel_offset(x); };
+	virtual bool truncatable(const infinint & pos) const override { return true; };
         virtual infinint get_position() const override { return offset; };
 
     protected :
@@ -81,6 +82,7 @@ namespace libdar
 	    set_offset(offset + siz);
 	};
 
+	virtual void inherited_truncate(const infinint & pos) override { if(pos < offset) offset = pos; };
 	virtual void inherited_sync_write() override {};
 	virtual void inherited_flush_read() override {};
 	virtual void inherited_terminate() override {};
