@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -217,6 +217,21 @@ namespace libdar
 	    throw Erange("pile::skip_relative", "Error: skip_relative() on empty stack");
     }
 
+    bool pile::truncatable(const infinint & pos) const
+    {
+	if(is_terminated())
+	    throw SRC_BUG;
+
+	if(stack.size() > 0)
+	{
+	    if(stack.back().ptr == nullptr)
+		throw SRC_BUG;
+	    return stack.back().ptr->truncatable(pos);
+	}
+	else
+	    throw Erange("pile::truncatable", "Error: truncatable() on empty stack");
+    }
+
     infinint pile::get_position() const
     {
 	if(is_terminated())
@@ -300,6 +315,18 @@ namespace libdar
 	    throw Erange("pile::skip", "Error: inherited_write() on empty stack");
     }
 
+    void pile::inherited_truncate(const infinint & pos)
+    {
+	if(stack.size() > 0)
+	{
+	    if(stack.back().ptr == nullptr)
+		throw SRC_BUG;
+	    stack.back().ptr->truncate(pos);
+	}
+	else
+	    throw Erange("pile::skip", "Error: inherited_write() on empty stack");
+    }
+
     void pile::sync_write_above(generic_file *ptr)
     {
 	deque<face>::reverse_iterator it = stack.rbegin();
