@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file pile.hpp
@@ -64,7 +64,7 @@ namespace libdar
 	    /// the pile is responsible of destroying this object if its destructor is called
 	    /// however, the pile object releases its responsibility about any object that
 	    /// will be poped (see pop() below) from the stack.
-	    /// \note empty label (empty string) is the only value that can be used for several objects of the stack
+	    /// \note empty label (empty string) is the only identical value that can be used for several objects of the stack
 	void push(generic_file *f, const std::string & label = "", bool extend_mode = false);
 
 	    /// remove the top generic_file from the top
@@ -148,6 +148,7 @@ namespace libdar
 	virtual bool skip(const infinint & pos) override;
 	virtual bool skip_to_eof() override;
 	virtual bool skip_relative(S_I x) override;
+	virtual bool truncatable(const infinint & amount) const override;
 	virtual infinint get_position() const override;
 
 	void copy_to(generic_file & ref) override;
@@ -157,6 +158,7 @@ namespace libdar
 	virtual void inherited_read_ahead(const infinint & amount) override;
 	virtual U_I inherited_read(char *a, U_I size) override;
 	virtual void inherited_write(const char *a, U_I size) override;
+	virtual void inherited_truncate(const infinint & pos) override;
 	virtual void inherited_sync_write() override;
 	virtual void inherited_flush_read() override;
 	virtual void inherited_terminate() override;
