@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file pile_descriptor.hpp
@@ -34,7 +34,7 @@ extern "C"
 
 #include "pile.hpp"
 #include "escape.hpp"
-#include "compressor.hpp"
+#include "proto_compressor.hpp"
 
 namespace libdar
 {
@@ -46,7 +46,7 @@ namespace libdar
     {
 	pile *stack;       ///< the stack to read from or write to (should never be equal to nullptr)
 	escape *esc;       ///< an escape layer in stack (may be nullptr)
-	compressor *compr; ///< a compressor layer in stack (should never be equal to nullptr)
+	proto_compressor *compr; ///< a compressor layer in stack (should never be equal to nullptr)
 	pile_descriptor() { stack = nullptr; esc = nullptr; compr = nullptr; };
 	pile_descriptor(pile *ptr);
 	void check(bool small) const; ///< check structure coherence with expected read/write mode (small or normal)
