@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -497,6 +497,33 @@ namespace libdar
         return true; // when x == 0
     }
 
+    bool sar::truncatable(const infinint & pos) const
+    {
+	infinint dest_file, offset;
+	infinint high_num;
+
+	    // locate the slice and relative offset where to cut
+
+	slicing.which_slice(pos,
+			    dest_file,
+			    offset);
+
+	if(of_last_file_known && of_last_file_num < dest_file)
+	    return true; // truncating after EOF
+
+	if(of_fd == nullptr)
+	    throw SRC_BUG;
+
+	if(dest_file < of_current)
+	    return of_fd->truncatable(0);
+	    // we test the ability to truncate for
+	    // the base objects
+	    // but we should also test the ability
+	    // to unlink()/delete a file from the entrepot
+	else
+	    return of_fd->truncatable(offset);
+    }
+
     infinint sar::get_position() const
     {
 	infinint delta = slicing.older_sar_than_v8 ? 0 : 1; // one byte less per slice with archive format >= 8
@@ -554,7 +581,7 @@ namespace libdar
 		tmp = 0; // simulating an end of slice
 
 	    if(tmp == 0)
-		if(of_flag == flag_type_terminal)
+                if(of_flag == flag_type_terminal || get_mode() != gf_read_only)
 		    loop = false;
 		else
 		    if(is_current_eof_a_normal_end_of_slice())
@@ -583,6 +610,48 @@ namespace libdar
         return lu;
     }
 
+    void sar::inherited_truncate(const infinint & pos)
+    {
+	infinint dest_file, offset;
+	infinint high_num;
+
+	    // locate the slice and relative offset where to cut
+
+	slicing.which_slice(pos,
+			    dest_file,
+			    offset);
+
+	if(of_last_file_known && of_last_file_num < dest_file)
+	    return; // nothing to do
+
+	    // must skip backward if we are in a slice following
+	    // the truncate position because we cannot keep the current slice opened
+	if(pos < get_position())
+	    skip(pos);
+
+	if(dest_file < of_current)
+	    throw SRC_BUG; // the previous skip() should have avoided this situation
+
+	if(dest_file > of_current)
+	    return; // truncating after eof, inherited_truncate should not expand a file
+
+	    // truncating the current slice to offset
+
+	if(of_fd == nullptr)
+	    throw SRC_BUG;
+
+	of_fd->truncate(offset);
+
+	    // removing slices after the current slice
+
+	sar_tools_remove_higher_slices_than(*entr,
+					    base,
+					    min_digits,
+					    ext,
+					    of_current,
+					    get_ui());
+    }
+
     void sar::inherited_write(const char *a, U_I to_write)
     {
         infinint max_at_once;
@@ -646,9 +715,6 @@ namespace libdar
 		}
 	    }
 
-		// telling the system to free this file from the cache
-	    of_fd->fadvise(fichier_global::advise_dontneed);
-
 	    of_fd->terminate();
             delete of_fd;
             of_fd = nullptr;
@@ -1182,7 +1248,10 @@ namespace libdar
 		    throw Erange("sar::sar", gettext("First slice size is too small to even just be able to drop the slice header"));
 		if(slicing.other_slice_header >= slicing.other_size)
 		    throw Erange("sar::sar", gettext("Slice size is too small to even just be able to drop the slice header"));
+		size_of_current = slicing.first_size;
 	    }
+	    else
+		size_of_current = slicing.other_size;
 	}
 	catch(...)
 	{
