@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file sar_tools.hpp
@@ -55,6 +55,14 @@ namespace libdar
 						   const infinint & min_digits,
 						   const std::string & ext, infinint & ret);
 
+    extern void sar_tools_remove_higher_slices_than(entrepot & entr,
+						    const std::string & base_name,
+						    const infinint & min_digits,
+						    const std::string & ext,
+						    const infinint & higher_slice_num_to_keep,
+						    user_interaction & ui);
+
+
     extern std::string sar_tools_make_padded_number(const std::string & num,
 						    const infinint & min_digits);
 
