@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -157,18 +157,34 @@ namespace libdar
 	mem[*string_size] = '\0';
     }
 
+    void secu_string::expand_string_size_to(U_I size)
+    {
+	if(size > get_allocated_size())
+	    throw Erange("secu_string::expand_string_size_to", gettext("Cannot expand secu_string size past its allocation size"));
+	if(size < *string_size)
+	    throw Erange("secu_stering::expand_string_size_to", gettext("Cannot shrink a secu_string"));
+
+	memset(mem + *string_size, '\0', size - *string_size);
+	*string_size = size;
+    }
+
     void secu_string::randomize(U_I size)
     {
 #if CRYPTO_AVAILABLE
-	if(size > get_allocated_size())
-	    throw Erange("secu_string::randomize", gettext("secu_string randomization requested exceeds storage capacity"));
-	*string_size = size;
+	set_size(size);
 	gcry_randomize(mem, *string_size, GCRY_STRONG_RANDOM);
 #else
 	throw Efeature("string randomization lacks libgcrypt");
 #endif
     }
 
+    void secu_string::set_size(U_I size)
+    {
+	if(size > get_allocated_size())
+	    throw Erange("secu_string::set_size", gettext("exceeding storage capacity while requesting secu_string::set_size()"));
+	*string_size = size;
+    }
+
     char & secu_string::operator[] (U_I index)
     {
 	if(index < get_size())
@@ -267,9 +283,8 @@ namespace libdar
 	}
 	if(mem != nullptr)
 	{
-	    if(allocated_size == nullptr)
-		throw SRC_BUG;
-	    (void)memset(mem, 0, *allocated_size);
+	    if(allocated_size != nullptr)
+		(void)memset(mem, 0, *allocated_size);
 #if CRYPTO_AVAILABLE
 	    gcry_free(mem);
 #else
