@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file secu_string.hpp
@@ -47,12 +47,8 @@ namespace libdar
 	/// class secu_string
 
 	/// it manages the allocation/release of a given size block of memory
-	/// and let the user feed it from a filedescriptor
-	/// and access to it under with a char* pointer.
-	/// if more constructor are needed (espetially toward API), tell me, but
-	/// this is a non-sens to build a secure string from another data structure which is
-	/// not yet secured, where from the set() method that fetches data directly from a
-	/// filedescriptor (set() low-level system call) which might be a tty for example
+	/// the memory block is forbidden to be swapped (if is_strin_secured() is true)
+	/// and is zeroed before being released
 
     class secu_string
     {
@@ -89,7 +85,7 @@ namespace libdar
 	secu_string & operator = (secu_string && ref) noexcept { move_from(std::move(ref)); return *this; };
 
 	    /// the destructor (set memory to zero before releasing it)
-        ~secu_string() noexcept(false) { clean_and_destroy(); };
+        ~secu_string() noexcept { clean_and_destroy(); };
 
 
 	bool operator != (const std::string & ref) const { return ! (*this == ref); };
@@ -132,6 +128,10 @@ namespace libdar
 	    /// \param[in] pos is the length of the string to set, it must be smaller or equal to the current size
 	void reduce_string_size_to(U_I pos);
 
+	    /// set the string size within the allocated secure memory
+	void expand_string_size_to(U_I size);
+
+
 	    /// clear the string (set to an empty string)
 	void clear() { *string_size = 0; };
 
@@ -149,7 +149,9 @@ namespace libdar
 
 	    /// \return the address of the first byte of the string
 	    /// \note check the "size" method to know how much bytes can be read
-	const char*c_str() const { return mem == nullptr ? throw SRC_BUG : mem; };
+	const char* c_str() const { return mem == nullptr ? throw SRC_BUG : mem; };
+	char* c_str() { return mem == nullptr ? throw SRC_BUG : mem; };
+	void set_size(U_I size);
 
 	    /// non constant flavor of direct secure memory access
 	char * get_array() { return mem == nullptr ? throw SRC_BUG : mem; };
