@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -357,6 +357,18 @@ namespace libdar
         }
     }
 
+    void storage::truncate(const infinint & pos)
+    {
+	if(pos < size())
+	{
+	    iterator it;
+	    infinint amount = size() - pos;
+
+	    it.skip_to(*this, pos);
+	    remove_bytes_at_iterator(it, amount);
+	}
+    }
+
     void storage::fusionne(struct cellule *a_first, struct cellule *a_last, struct cellule *b_first, struct cellule *b_last,
                            struct cellule *&res_first, struct cellule * & res_last)
     {
