@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file storage.hpp
@@ -175,6 +175,7 @@ namespace libdar
         void insert_as_much_as_necessary_const_byte_to_be_as_wider_as(const storage & ref, const iterator & it, unsigned char value);
         void remove_bytes_at_iterator(iterator it, U_I number);
         void remove_bytes_at_iterator(iterator it, infinint number);
+	void truncate(const infinint & pos);
 
     private:
         struct cellule *first, *last;
