@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -425,11 +425,6 @@ namespace libdar
 		throw SRC_BUG;
 	    }
 
-		// telling the system to free this file from the cache, when relying on a plain file
-	    fichier_global *ref_fic = dynamic_cast<fichier_global *>(reference);
-	    if(ref_fic != nullptr)
-		ref_fic->fadvise(fichier_global::advise_dontneed);
-
 	    reference->terminate();
 	    delete reference; // this closes the slice so we can now eventually play with it:
 	    reference = nullptr;
