@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file trivial_sar.hpp
@@ -111,6 +111,7 @@ namespace libdar
         virtual bool skip(const infinint & pos) override;
         virtual bool skip_to_eof() override { if(is_terminated()) throw SRC_BUG; return reference->skip_to_eof(); };
         virtual bool skip_relative(S_I x) override;
+	virtual bool truncatable(const infinint & pos) const override { return reference->truncatable(offset + pos); };
         virtual infinint get_position() const override { return cur_pos; };
 
 	    // contextual inherited method
@@ -130,6 +131,7 @@ namespace libdar
 	virtual void inherited_read_ahead(const infinint & amount) override { reference->read_ahead(amount); };
         virtual U_I inherited_read(char *a, U_I size) override;
         virtual void inherited_write(const char *a, U_I size) override;
+	virtual void inherited_truncate(const infinint & pos) override { reference->truncate(pos + offset); cur_pos = pos; };
 	virtual void inherited_sync_write() override { if(reference != nullptr) reference->sync_write(); };
 	virtual void inherited_flush_read() override { if(reference != nullptr) reference->flush_read(); };
 	virtual void inherited_terminate() override;
