@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -324,6 +324,20 @@ namespace libdar
 	current += wrote;
     }
 
+    void tronc::inherited_truncate(const infinint & pos)
+    {
+	if(limited)
+	{
+	    if(pos < sz)
+		ref->truncate(start + pos);
+		// else there is nothing to do
+	}
+	else
+	    ref->truncate(start + pos);
+
+	set_back_current_position();
+    }
+
     void tronc::set_back_current_position()
     {
 	if(is_terminated())
