@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file tronc.hpp
@@ -81,6 +81,7 @@ namespace libdar
 	    /// inherited from generic_file
         virtual bool skip_relative(S_I x) override;
 	    /// inherited from generic_file
+	virtual bool truncatable(const infinint & pos) const override { return ref->truncatable(start + pos); };
         virtual infinint get_position() const override { return current; };
 
 	    /// when a tronc is used over a compressor, it becomes necessary to disable position check
@@ -100,6 +101,7 @@ namespace libdar
         virtual U_I inherited_read(char *a, U_I size) override;
 	    /// inherited from generic_file
         virtual void inherited_write(const char *a, U_I size) override;
+	virtual void inherited_truncate(const infinint & pos) override;
 	virtual void inherited_sync_write() override { ref->sync_write(); }
 	virtual void inherited_flush_read() override {};
 	virtual void inherited_terminate() override {if(own_ref) ref->terminate(); };
