@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -55,7 +55,10 @@ using namespace std;
 namespace libdar
 {
 
-    tronconneuse::tronconneuse(U_32 block_size, generic_file & encrypted_side, bool no_initial_shift, const archive_version & x_reading_ver) : generic_file(encrypted_side.get_mode() == gf_read_only ? gf_read_only : gf_write_only)
+    tronconneuse::tronconneuse(U_32 block_size,
+			       generic_file & encrypted_side,
+			       const archive_version & x_reading_ver,
+			       std::unique_ptr<crypto_module> & ptr) : proto_tronco(encrypted_side.get_mode() == gf_read_only ? gf_read_only : gf_write_only)
     {
 	if(block_size == 0)
 	    throw Erange("tronconneuse::tronconneuse", tools_printf(gettext("%d is not a valid block size"), block_size));
@@ -65,10 +68,7 @@ namespace libdar
 	buf = nullptr;  // cannot invoke pure virtual methods from constructor
 	clear_block_size = block_size;
 	current_position = 0;
-	if(no_initial_shift)
-	    initial_shift = 0;
-	else
-	    initial_shift = encrypted_side.get_position();
+	initial_shift = 0;
 	block_num = 0;
 	encrypted = & encrypted_side;
 	encrypted_buf = nullptr; // cannot invoke pure virtual methods from constructor
@@ -80,6 +80,9 @@ namespace libdar
 	weof = false;
 	reof = false;
 	reading_ver = x_reading_ver;
+	crypto = move(ptr);
+	if(!crypto)
+	    throw Erange("tronconneuse::tronconneuse", "null pointer given as crypto_module to tronconneuse");
 	trailing_clear_data = nullptr;
 
 	    // buffers cannot be initialized here as they need result from pure virtual methods
@@ -88,15 +91,6 @@ namespace libdar
 	    // has not been initialized.
     }
 
-
-    tronconneuse & tronconneuse::operator = (const tronconneuse & ref)
-    {
-	detruit();
-	generic_file::operator = (ref);
-
-	return *this;
-    }
-
     bool tronconneuse::skippable(skippability direction, const infinint & amount)
     {
 	if(is_terminated())
@@ -223,7 +217,7 @@ namespace libdar
 	{
 	    interim = 0;
 	    x_amount.unstack(interim);
-	    new_amount += encrypted_block_size_for(interim);
+	    new_amount += crypto->encrypted_block_size_for(interim);
 	}
 
 	encrypted->read_ahead(new_amount);
@@ -312,6 +306,7 @@ namespace libdar
 	encrypted_buf_size = 0;
 	encrypted_buf_data = 0;
 	extra_buf_size = 0;
+	crypto.reset();
 	extra_buf_data = 0;
     }
 
@@ -363,6 +358,10 @@ namespace libdar
 	    weof = ref.weof;
 	    reof = ref.reof;
 	    reading_ver = ref.reading_ver;
+	    if(ref.crypto)
+		crypto = ref.crypto->clone();
+	    else
+		crypto.reset();
 	    trailing_clear_data = ref.trailing_clear_data;
 	}
 	catch(...)
@@ -392,6 +391,7 @@ namespace libdar
 	weof = move(ref.weof);
 	reof = move(ref.reof);
 	reading_ver = move(ref.reading_ver);
+	crypto = move(ref.crypto);
 	trailing_clear_data = move(ref.trailing_clear_data);
     }
 
@@ -436,7 +436,7 @@ namespace libdar
 
 		try
 		{
-		    buf_byte_data = decrypt_data(block_num, encrypted_buf, encrypted_buf_data, buf, buf_size);
+		    buf_byte_data = crypto->decrypt_data(block_num, encrypted_buf, encrypted_buf_data, buf, buf_size);
 		}
 		catch(Erange & e)
 		{
@@ -447,7 +447,7 @@ namespace libdar
 			    remove_trailing_clear_data_from_encrypted_buf(crypt_offset);
 
 				// retrying but without trailing cleared data
-			    buf_byte_data = decrypt_data(block_num, encrypted_buf, encrypted_buf_data, buf, buf_size);
+			    buf_byte_data = crypto->decrypt_data(block_num, encrypted_buf, encrypted_buf_data, buf, buf_size);
 			}
 			catch(Egeneric & f)
 			{
@@ -489,7 +489,7 @@ namespace libdar
 	if(buf_byte_data > 0)
 	{
 	    init_buf();
-	    encrypted_buf_data = encrypt_data(block_num, buf, buf_byte_data, buf_size, encrypted_buf, encrypted_buf_size);
+	    encrypted_buf_data = crypto->encrypt_data(block_num, buf, buf_byte_data, buf_size, encrypted_buf, encrypted_buf_size);
 	    try
 	    {
 		encrypted->write(encrypted_buf, encrypted_buf_data);
@@ -525,7 +525,7 @@ namespace libdar
 	if(encrypted_buf == nullptr)
 	{
 	    encrypted_buf_data = 0;
-	    encrypted_buf_size = encrypted_block_size_for(clear_block_size);
+	    encrypted_buf_size = crypto->encrypted_block_size_for(clear_block_size);
 	    encrypted_buf = new (nothrow) char[encrypted_buf_size];
 	    if(encrypted_buf == nullptr)
 	    {
@@ -536,7 +536,7 @@ namespace libdar
 	if(buf == nullptr)
 	{
 	    buf_byte_data = 0;
-	    buf_size = clear_block_allocated_size_for(clear_block_size);
+	    buf_size = crypto->clear_block_allocated_size_for(clear_block_size);
 	    if(buf_size < clear_block_size)
 		throw SRC_BUG; // buf_size must be larger than or equal to clear_block_size
 	    buf = new (nothrow) char[buf_size];
