@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -433,7 +433,7 @@ namespace libdar
 	bool eof = false;
 
 
-	max_i_step = int_tools_maxof_agregate(max_i_step);
+	max_i_step = int_tools_maxof_aggregate(max_i_step);
 	if(max_i_step <= 0)
 	    throw SRC_BUG; // error in max positive value calculation, just above
 
