@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file tuyau.hpp
@@ -83,6 +83,7 @@ namespace libdar
         virtual bool skip(const infinint & pos) override;
         virtual bool skip_to_eof() override;
         virtual bool skip_relative(signed int x) override;
+	virtual bool truncatable(const infinint & pos) const override { return pos >= position; };
         virtual infinint get_position() const override { return position; };
 
 	bool has_next_to_read();
@@ -91,6 +92,7 @@ namespace libdar
 	virtual void inherited_read_ahead(const infinint & amount) override {}; // relying on the operating system
         virtual U_I inherited_read(char *a, U_I size) override;
         virtual void inherited_write(const char *a, U_I size) override;
+	virtual void inherited_truncate(const infinint & pos) override { if(pos < position) throw SRC_BUG; };
 	virtual void inherited_sync_write() override {};
 	virtual void inherited_flush_read() override {};
 	virtual void inherited_terminate() override;
