@@ -16,18 +16,19 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file zapette.hpp
     /// \brief remote control between dar and dar_slave.
     /// \ingroup Private
     ///
-    /// Two classes are defined in this module
+    /// Two objects communicate through a paire of pipes:
     /// - zapette is the dar side master class
     /// - slave_zapette dar_slave side
     /// .
-    /// these two classes communicate throw a pair pipes
+    /// they form a communication channel between dar/libdar (zapette side)
+    /// and dar_slave/libdar (dar_slave side)
 
 #ifndef ZAPETTE_HPP
 #define ZAPETTE_HPP
@@ -74,6 +75,7 @@ namespace libdar
         virtual bool skip(const infinint &pos) override;
         virtual bool skip_to_eof() override { if(is_terminated()) throw SRC_BUG; position = file_size; return true; };
         virtual bool skip_relative(S_I x) override;
+	virtual bool truncatable(const infinint & pos) const override { return false; };
         virtual infinint get_position() const override { if(is_terminated()) throw SRC_BUG; return position; };
 
 	    // overwritten inherited methods from contextual
@@ -95,6 +97,7 @@ namespace libdar
 	virtual void inherited_read_ahead(const infinint & amount) override {}; // optimization will be done when zapette will use the messaging_encode/decode exchange format
         virtual U_I inherited_read(char *a, U_I size) override;
         virtual void inherited_write(const char *a, U_I size) override;
+	virtual void inherited_truncate(const infinint & pos) override { throw SRC_BUG; }; // read only object
 	virtual void inherited_sync_write() override {};
 	virtual void inherited_flush_read() override {};
 	virtual void inherited_terminate() override;
