@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
     /// \file my_config.h
@@ -29,7 +29,7 @@
 #if HAVE_CONFIG_H
 #define NODUMP_LINUX 0
 #define NODUMP_EXT2FS 1
-#include "../config.h"
+#include "config.h"
 
     // workaround for autoconf 2.59
 #undef mbstate_t
