@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 
@@ -882,7 +882,8 @@ PYBIND11_MODULE(libdar, mod)
 	.def("clear", &libdar::secu_string::clear)
 	.def("resize", &libdar::secu_string::resize)
 	.def("randomize", &libdar::secu_string::randomize)
-	.def("c_str", &libdar::secu_string::c_str, pybind11::return_value_policy::reference_internal)
+	.def("c_str", (char* (libdar::secu_string::*)()) &libdar::secu_string::c_str, pybind11::return_value_policy::reference_internal)
+	.def("c_str", (const char* (libdar::secu_string::*)() const) &libdar::secu_string::c_str, pybind11::return_value_policy::reference_internal)
 	.def("get_array", &libdar::secu_string::get_array, pybind11::return_value_policy::reference_internal)
 	.def("at", [](libdar::secu_string & self, libdar::U_I index) { return std::string(1, self[index]); }) // not a temporary secure storage but no char type in python... so
 	.def("get_size", &libdar::secu_string::get_size)
@@ -1188,6 +1189,7 @@ PYBIND11_MODULE(libdar, mod)
 	static bool libbz2() noexcept { return libdar::compile_time::libbz2(); };
 	static bool liblzo() noexcept { return libdar::compile_time::liblzo(); };
 	static bool libxz() noexcept { return libdar::compile_time::libxz(); };
+	static bool libzstd() noexcept { return libdar::compile_time::libzstd(); };
 	static bool libgcrypt() noexcept { return libdar::compile_time::libgcrypt(); };
 	static bool furtive_read() noexcept { return libdar::compile_time::furtive_read(); };
 	static bool system_endian() noexcept { return libdar::compile_time::system_endian(); };
@@ -1196,7 +1198,9 @@ PYBIND11_MODULE(libdar, mod)
 	static bool FSA_linux_extX() noexcept { return libdar::compile_time::FSA_linux_extX(); };
 	static bool FSA_birthtime() noexcept { return libdar::compile_time::FSA_birthtime(); };
 	static bool microsecond_read() noexcept { return libdar::compile_time::microsecond_read(); };
+	static bool nanosecond_read() noexcept { return libdar::compile_time::nanosecond_read(); };
 	static bool microsecond_write() noexcept { return libdar::compile_time::microsecond_write(); };
+	static bool nanosecond_write() noexcept { return libdar::compile_time::nanosecond_write(); };
 	static bool symlink_restore_dates() noexcept { return libdar::compile_time::symlink_restore_dates(); };
 	static bool public_key_cipher() noexcept { return libdar::compile_time::public_key_cipher(); };
 	static bool libthreadar() noexcept { return libdar::compile_time::libthreadar(); };
@@ -1223,6 +1227,7 @@ PYBIND11_MODULE(libdar, mod)
 	.def_static("libbz2", &compile_time::libbz2)
 	.def_static("liblzo", &compile_time::liblzo)
 	.def_static("libxz", &compile_time::libxz)
+	.def_static("libzstd", &compile_time::libzstd)
 	.def_static("libgcrypt", &compile_time::libgcrypt)
 	.def_static("furtive_read", &compile_time::furtive_read)
 	.def_static("system_endian", &compile_time::system_endian)
@@ -1258,7 +1263,8 @@ PYBIND11_MODULE(libdar, mod)
 	.value("none", libdar::hash_algo::none)
 	.value("md5", libdar::hash_algo::md5)
 	.value("sha1", libdar::hash_algo::sha1)
-	.value("sha512", libdar::hash_algo::sha512);
+	.value("sha512", libdar::hash_algo::sha512)
+	.value("argon2", libdar::hash_algo::argon2);
 
     mod.def("hash_algo_to_string", &libdar::hash_algo_to_string);
     mod.def("string_to_hash_algo", [](const std::string & arg)
@@ -1279,7 +1285,9 @@ PYBIND11_MODULE(libdar, mod)
 	.value("lzo", libdar::compression::lzo)
 	.value("xz", libdar::compression::xz)
 	.value("lzo1x_1_15", libdar::compression::lzo1x_1_15)
-	.value("lzo1x_1", libdar::compression::lzo1x_1);
+	.value("lzo1x_1", libdar::compression::lzo1x_1)
+	.value("zstd", libdar::compression::zstd)
+	.value("lz4", libdar::compression::lz4);
 
     mod.def("compression2string", &libdar::compression2string);
     mod.def("string2compression", &libdar::string2compression);
@@ -1331,6 +1339,8 @@ PYBIND11_MODULE(libdar, mod)
 	.def("set_entrepot", &libdar::archive_options_read::set_entrepot)
 	.def("set_ignore_signature_check_failure", &libdar::archive_options_read::set_ignore_signature_check_failure)
 	.def("set_multi_threaded", &libdar::archive_options_read::set_multi_threaded)
+	.def("set_multi_threaded_crypto", &libdar::archive_options_read::set_multi_threaded_crypto)
+	.def("set_multi_threaded_compress", &libdar::archive_options_read::set_multi_threaded_compress)
 	.def("set_external_catalogue", &libdar::archive_options_read::set_external_catalogue)
 	.def("unset_external_catalogue", &libdar::archive_options_read::unset_external_catalogue)
 	.def("set_ref_crypto_algo", &libdar::archive_options_read::set_ref_crypto_algo)
@@ -1358,6 +1368,7 @@ PYBIND11_MODULE(libdar, mod)
 	.def("set_empty_dir", &libdar::archive_options_create::set_empty_dir)
 	.def("set_compression", &libdar::archive_options_create::set_compression)
 	.def("set_compression_level", &libdar::archive_options_create::set_compression_level)
+	.def("set_compression_block_size", &libdar::archive_options_create::set_compression_block_size)
 	.def("set_slicing", &libdar::archive_options_create::set_slicing)
 	.def("set_ea_mask", &libdar::archive_options_create::set_ea_mask)
 	.def("set_execute", &libdar::archive_options_create::set_execute)
@@ -1394,6 +1405,8 @@ PYBIND11_MODULE(libdar, mod)
 	.def("set_entrepot", &libdar::archive_options_create::set_entrepot)
 	.def("set_fsa_scope", &libdar::archive_options_create::set_fsa_scope)
 	.def("set_multi_threaded", &libdar::archive_options_create::set_multi_threaded)
+	.def("set_multi_threaded_crypto", &libdar::archive_options_create::set_multi_threaded_crypto)
+	.def("set_multi_threaded_compress", &libdar::archive_options_create::set_multi_threaded_compress)
 	.def("set_delta_diff", &libdar::archive_options_create::set_delta_diff)
 	.def("set_delta_signature", &libdar::archive_options_create::set_delta_signature)
 	.def("set_delta_mask", &libdar::archive_options_create::set_delta_mask)
@@ -1414,6 +1427,7 @@ PYBIND11_MODULE(libdar, mod)
 	.def("set_pause", &libdar::archive_options_isolate::set_pause)
 	.def("set_compression", &libdar::archive_options_isolate::set_compression)
 	.def("set_compression_level", &libdar::archive_options_isolate::set_compression_level)
+	.def("set_compression_block_size", &libdar::archive_options_isolate::set_compression_block_size)
 	.def("set_slicing", &libdar::archive_options_isolate::set_slicing)
 	.def("set_execute", &libdar::archive_options_isolate::set_execute)
 	.def("set_crypto_algo", &libdar::archive_options_isolate::set_crypto_algo)
@@ -1431,6 +1445,8 @@ PYBIND11_MODULE(libdar, mod)
 	.def("set_sequential_marks", &libdar::archive_options_isolate::set_sequential_marks)
 	.def("set_entrepot", &libdar::archive_options_isolate::set_entrepot)
 	.def("set_multi_threaded", &libdar::archive_options_isolate::set_multi_threaded)
+	.def("set_multi_threaded_crypto", &libdar::archive_options_isolate::set_multi_threaded_crypto)
+	.def("set_multi_threaded_compress", &libdar::archive_options_isolate::set_multi_threaded_compress)
 	.def("set_delta_signature", &libdar::archive_options_isolate::set_delta_signature)
 	.def("set_delta_mask", &libdar::archive_options_isolate::set_delta_mask)
 	.def("set_delta_sig_min_size", &libdar::archive_options_isolate::set_delta_sig_min_size)
@@ -1455,6 +1471,7 @@ PYBIND11_MODULE(libdar, mod)
 	.def("set_empty_dir", &libdar::archive_options_merge::set_empty_dir)
 	.def("set_compression", &libdar::archive_options_merge::set_compression)
 	.def("set_compression_level", &libdar::archive_options_merge::set_compression_level)
+	.def("set_compression_block_size", &libdar::archive_options_merge::set_compression_block_size)
 	.def("set_slicing", &libdar::archive_options_merge::set_slicing)
 	.def("set_ea_mask", &libdar::archive_options_merge::set_ea_mask)
 	.def("set_execute", &libdar::archive_options_merge::set_execute)
@@ -1479,6 +1496,8 @@ PYBIND11_MODULE(libdar, mod)
 	.def("set_entrepot", &libdar::archive_options_merge::set_entrepot)
 	.def("set_fsa_scope", &libdar::archive_options_merge::set_fsa_scope)
 	.def("set_mutli_threaded", &libdar::archive_options_merge::set_multi_threaded)
+	.def("set_mutli_threaded_crypto", &libdar::archive_options_merge::set_multi_threaded_crypto)
+	.def("set_multi_threaded_compress", &libdar::archive_options_merge::set_multi_threaded_compress)
 	.def("set_delta_signature", &libdar::archive_options_merge::set_delta_signature)
 	.def("set_delta_mask", &libdar::archive_options_merge::set_delta_mask)
 	.def("set_delta_sig_min_size", &libdar::archive_options_merge::set_delta_sig_min_size)
@@ -1581,8 +1600,9 @@ PYBIND11_MODULE(libdar, mod)
 	.def("set_hash_algo", &libdar::archive_options_repair::set_hash_algo)
 	.def("set_slice_min_digits", &libdar::archive_options_repair::set_slice_min_digits)
 	.def("set_entrepot", &libdar::archive_options_repair::set_entrepot)
-	.def("set_multi_threaded", &libdar::archive_options_repair::set_multi_threaded);
-
+	.def("set_multi_threaded", &libdar::archive_options_repair::set_multi_threaded)
+	.def("set_multi_threaded_crypto", &libdar::archive_options_repair::set_multi_threaded_crypto)
+	.def("set_multi_threaded_compress", &libdar::archive_options_repair::set_multi_threaded_compress);
 
 
 	//////////////////////////////////////////
