@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -43,6 +43,7 @@ extern "C"
 #include "fichier_local.hpp"
 #include "pile.hpp"
 #include "tools.hpp"
+#include "compressor.hpp"
 
 using namespace libdar;
 using namespace std;
@@ -234,7 +235,7 @@ void f2()
 
         unlink(FIC1);
         fichier_local *f = new fichier_local(ui, FIC1, gf_read_write, 0644, false, true, false);
-	compressor *comp = new compressor(compression::none, f, 1);
+	compressor *comp = new compressor(compression::none, *f, 1);
 	pile stack;
 	pile_descriptor pdesc;
 
