@@ -16,7 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
-// to contact the author : http://dar.linux.free.fr/email.html
+// to contact the author, see the AUTHOR file
 /*********************************************************************/
 
 #include "../my_config.h"
@@ -65,7 +65,7 @@ int main(int argc, char *argv[])
     }
     catch(Egeneric & e)
     {
-	cout << "Execption caught: " << e.get_message() << endl;
+	cout << "Execption caught: " << e.dump_str() << endl;
     }
 }
 
@@ -202,6 +202,7 @@ void f1(int argc, char *argv[])
 	try
 	{
 	    readme.copy_to(*remotew);
+	    remotew->terminate();
 	}
 	catch(...)
 	{
